Class: Google::Apis::CloudidentityV1beta1::ApproveDeviceUserRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Request message for approving the device to access user data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApproveDeviceUserRequest

Returns a new instance of ApproveDeviceUserRequest.



183
184
185
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customerString

Optional. Resource name of the customer. If you're using this API for your own organization, use customers/my_customer If you're using this API to manage another organization, use customers/customer_id`, where customer_id is the customer to whom the device belongs. Corresponds to the JSON propertycustomer`

Returns:

  • (String)


181
182
183
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 181

def customer
  @customer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



188
189
190
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 188

def update!(**args)
  @customer = args[:customer] if args.key?(:customer)
end