Class: Google::Apis::CloudidentityV1beta1::ApproveDeviceUserResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Response message for approving the device to access user data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApproveDeviceUserResponse

Returns a new instance of ApproveDeviceUserResponse.



203
204
205
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_userGoogle::Apis::CloudidentityV1beta1::DeviceUser

Represents a user's use of a Device in the Cloud Identity Devices API. A DeviceUser is a resource representing a user's use of a Device Corresponds to the JSON property deviceUser



201
202
203
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 201

def device_user
  @device_user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



208
209
210
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 208

def update!(**args)
  @device_user = args[:device_user] if args.key?(:device_user)
end