Class: Google::Apis::CloudidentityV1beta1::BrowserAttributes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Contains information about browser profiles reported by the clients on the device (e.g. Endpoint Verification extension).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BrowserAttributes

Returns a new instance of BrowserAttributes.



281
282
283
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chrome_browser_infoGoogle::Apis::CloudidentityV1beta1::BrowserInfo

Browser-specific fields reported by clients on the device, such as Endpoint Verification extension. Corresponds to the JSON property chromeBrowserInfo



267
268
269
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 267

def chrome_browser_info
  @chrome_browser_info
end

#chrome_profile_idString

Chrome profile ID that is exposed by the Chrome API. It is unique for each device. Corresponds to the JSON property chromeProfileId

Returns:

  • (String)


273
274
275
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 273

def chrome_profile_id
  @chrome_profile_id
end

#last_profile_sync_timeString

Timestamp in milliseconds since the Unix epoch when the profile/gcm id was last synced. Corresponds to the JSON property lastProfileSyncTime

Returns:

  • (String)


279
280
281
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 279

def last_profile_sync_time
  @last_profile_sync_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



286
287
288
289
290
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 286

def update!(**args)
  @chrome_browser_info = args[:chrome_browser_info] if args.key?(:chrome_browser_info)
  @chrome_profile_id = args[:chrome_profile_id] if args.key?(:chrome_profile_id)
  @last_profile_sync_time = args[:last_profile_sync_time] if args.key?(:last_profile_sync_time)
end