Class: Google::Apis::CloudidentityV1beta1::CheckTransitiveMembershipResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::CheckTransitiveMembershipResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
The response message for MembershipsService.CheckTransitiveMembership.
Instance Attribute Summary collapse
-
#has_membership ⇒ Boolean
(also: #has_membership?)
Response does not include the possible roles of a member since the behavior of this rpc is not all-or-nothing unlike the other rpcs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckTransitiveMembershipResponse
constructor
A new instance of CheckTransitiveMembershipResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckTransitiveMembershipResponse
Returns a new instance of CheckTransitiveMembershipResponse.
670 671 672 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#has_membership ⇒ Boolean Also known as: has_membership?
Response does not include the possible roles of a member since the behavior of
this rpc is not all-or-nothing unlike the other rpcs. So, it may not be
possible to list all the roles definitively, due to possible lack of
authorization in some of the paths.
Corresponds to the JSON property hasMembership
667 668 669 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 667 def has_membership @has_membership end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
675 676 677 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 675 def update!(**args) @has_membership = args[:has_membership] if args.key?(:has_membership) end |