Class: Google::Apis::CloudidentityV1beta1::ChromePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Represents a Chrome policy and its current state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChromePolicy

Returns a new instance of ChromePolicy.



715
716
717
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflictsArray<Google::Apis::CloudidentityV1beta1::PolicyConflict>

Output only. A list of other policy values for the same policy name that were not applied due to lower precedence. This field is empty if there were no conflicts. Corresponds to the JSON property conflicts



689
690
691
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 689

def conflicts
  @conflicts
end

#nameString

Output only. The unique name of the Chrome policy. These names correspond to the policy names listed in Chrome Enterprise Policy List Corresponds to the JSON property name

Returns:

  • (String)


696
697
698
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 696

def name
  @name
end

#scopeString

Output only. The scope at which the applied policy value is set (USER or MACHINE). Corresponds to the JSON property scope

Returns:

  • (String)


702
703
704
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 702

def scope
  @scope
end

#sourceString

Output only. The source from which the applied policy value originated. Corresponds to the JSON property source

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 707

def source
  @source
end

#valueString

Output only. The currently applied value of the policy. The format depends on the policy type (e.g., boolean, string, JSON array/object). Corresponds to the JSON property value

Returns:

  • (String)


713
714
715
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 713

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



720
721
722
723
724
725
726
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 720

def update!(**args)
  @conflicts = args[:conflicts] if args.key?(:conflicts)
  @name = args[:name] if args.key?(:name)
  @scope = args[:scope] if args.key?(:scope)
  @source = args[:source] if args.key?(:source)
  @value = args[:value] if args.key?(:value)
end