Class: Google::Apis::CloudidentityV1beta1::GetMembershipGraphResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

The response message for MembershipsService.GetMembershipGraph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetMembershipGraphResponse

Returns a new instance of GetMembershipGraphResponse.



1517
1518
1519
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjacency_listArray<Google::Apis::CloudidentityV1beta1::MembershipAdjacencyList>

The membership graph's path information represented as an adjacency list. Corresponds to the JSON property adjacencyList



1508
1509
1510
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1508

def adjacency_list
  @adjacency_list
end

#groupsArray<Google::Apis::CloudidentityV1beta1::Group>

The resources representing each group in the adjacency list. Each group in this list can be correlated to a 'group' of the MembershipAdjacencyList using the 'name' of the Group resource. Corresponds to the JSON property groups



1515
1516
1517
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1515

def groups
  @groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1522
1523
1524
1525
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1522

def update!(**args)
  @adjacency_list = args[:adjacency_list] if args.key?(:adjacency_list)
  @groups = args[:groups] if args.key?(:groups)
end