Class: Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1BrowserInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Browser-specific fields reported by the Endpoint Verification extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1BrowserInfo

Returns a new instance of GoogleAppsCloudidentityDevicesV1BrowserInfo.



1837
1838
1839
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#browser_management_stateString

Output only. Browser's management state. Corresponds to the JSON property browserManagementState

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1742

def browser_management_state
  @browser_management_state
end

#browser_versionString

Version of the request initiating browser. E.g. 91.0.4442.4. Corresponds to the JSON property browserVersion

Returns:

  • (String)


1747
1748
1749
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1747

def browser_version
  @browser_version
end

#is_built_in_dns_client_enabledBoolean Also known as: is_built_in_dns_client_enabled?

Current state of built-in DNS client. Corresponds to the JSON property isBuiltInDnsClientEnabled

Returns:

  • (Boolean)


1753
1754
1755
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1753

def is_built_in_dns_client_enabled
  @is_built_in_dns_client_enabled
end

#is_bulk_data_entry_analysis_enabledBoolean Also known as: is_bulk_data_entry_analysis_enabled?

Current state of [bulk data analysis](https://chromeenterprise.google/policies/

OnBulkDataEntryEnterpriseConnector). Set to true if provider list from Chrome

is non-empty. Corresponds to the JSON property isBulkDataEntryAnalysisEnabled

Returns:

  • (Boolean)


1761
1762
1763
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1761

def is_bulk_data_entry_analysis_enabled
  @is_bulk_data_entry_analysis_enabled
end

#is_chrome_cleanup_enabledBoolean Also known as: is_chrome_cleanup_enabled?

Deprecated: This field is not used for Chrome version 118 and later. Current state of Chrome Cleanup. Corresponds to the JSON property isChromeCleanupEnabled

Returns:

  • (Boolean)


1769
1770
1771
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1769

def is_chrome_cleanup_enabled
  @is_chrome_cleanup_enabled
end

#is_chrome_remote_desktop_app_blockedBoolean Also known as: is_chrome_remote_desktop_app_blocked?

Current state of Chrome Remote Desktop app. Corresponds to the JSON property isChromeRemoteDesktopAppBlocked

Returns:

  • (Boolean)


1776
1777
1778
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1776

def is_chrome_remote_desktop_app_blocked
  @is_chrome_remote_desktop_app_blocked
end

#is_file_download_analysis_enabledBoolean Also known as: is_file_download_analysis_enabled?

Current state of file download analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isFileDownloadAnalysisEnabled

Returns:

  • (Boolean)


1784
1785
1786
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1784

def is_file_download_analysis_enabled
  @is_file_download_analysis_enabled
end

#is_file_upload_analysis_enabledBoolean Also known as: is_file_upload_analysis_enabled?

Current state of file upload analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isFileUploadAnalysisEnabled

Returns:

  • (Boolean)


1792
1793
1794
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1792

def is_file_upload_analysis_enabled
  @is_file_upload_analysis_enabled
end

#is_realtime_url_check_enabledBoolean Also known as: is_realtime_url_check_enabled?

Current state of real-time URL check. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isRealtimeUrlCheckEnabled

Returns:

  • (Boolean)


1800
1801
1802
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1800

def is_realtime_url_check_enabled
  @is_realtime_url_check_enabled
end

#is_security_event_analysis_enabledBoolean Also known as: is_security_event_analysis_enabled?

Current state of security event analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isSecurityEventAnalysisEnabled

Returns:

  • (Boolean)


1808
1809
1810
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1808

def is_security_event_analysis_enabled
  @is_security_event_analysis_enabled
end

#is_site_isolation_enabledBoolean Also known as: is_site_isolation_enabled?

Current state of site isolation. Corresponds to the JSON property isSiteIsolationEnabled

Returns:

  • (Boolean)


1815
1816
1817
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1815

def is_site_isolation_enabled
  @is_site_isolation_enabled
end

#is_third_party_blocking_enabledBoolean Also known as: is_third_party_blocking_enabled?

Current state of third-party blocking. Corresponds to the JSON property isThirdPartyBlockingEnabled

Returns:

  • (Boolean)


1822
1823
1824
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1822

def is_third_party_blocking_enabled
  @is_third_party_blocking_enabled
end

#password_protection_warning_triggerString

Current state of password protection trigger. Corresponds to the JSON property passwordProtectionWarningTrigger

Returns:

  • (String)


1829
1830
1831
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1829

def password_protection_warning_trigger
  @password_protection_warning_trigger
end

#safe_browsing_protection_levelString

Current state of Safe Browsing protection level. Corresponds to the JSON property safeBrowsingProtectionLevel

Returns:

  • (String)


1835
1836
1837
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1835

def safe_browsing_protection_level
  @safe_browsing_protection_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1842

def update!(**args)
  @browser_management_state = args[:browser_management_state] if args.key?(:browser_management_state)
  @browser_version = args[:browser_version] if args.key?(:browser_version)
  @is_built_in_dns_client_enabled = args[:is_built_in_dns_client_enabled] if args.key?(:is_built_in_dns_client_enabled)
  @is_bulk_data_entry_analysis_enabled = args[:is_bulk_data_entry_analysis_enabled] if args.key?(:is_bulk_data_entry_analysis_enabled)
  @is_chrome_cleanup_enabled = args[:is_chrome_cleanup_enabled] if args.key?(:is_chrome_cleanup_enabled)
  @is_chrome_remote_desktop_app_blocked = args[:is_chrome_remote_desktop_app_blocked] if args.key?(:is_chrome_remote_desktop_app_blocked)
  @is_file_download_analysis_enabled = args[:is_file_download_analysis_enabled] if args.key?(:is_file_download_analysis_enabled)
  @is_file_upload_analysis_enabled = args[:is_file_upload_analysis_enabled] if args.key?(:is_file_upload_analysis_enabled)
  @is_realtime_url_check_enabled = args[:is_realtime_url_check_enabled] if args.key?(:is_realtime_url_check_enabled)
  @is_security_event_analysis_enabled = args[:is_security_event_analysis_enabled] if args.key?(:is_security_event_analysis_enabled)
  @is_site_isolation_enabled = args[:is_site_isolation_enabled] if args.key?(:is_site_isolation_enabled)
  @is_third_party_blocking_enabled = args[:is_third_party_blocking_enabled] if args.key?(:is_third_party_blocking_enabled)
  @password_protection_warning_trigger = args[:password_protection_warning_trigger] if args.key?(:password_protection_warning_trigger)
  @safe_browsing_protection_level = args[:safe_browsing_protection_level] if args.key?(:safe_browsing_protection_level)
end