Class: Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1Device

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

A Device within the Cloud Identity Devices API. Represents a Device known to Google Cloud, independent of the device ownership, type, and whether it is assigned or in use by a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1Device

Returns a new instance of GoogleAppsCloudidentityDevicesV1Device.



2408
2409
2410
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_specific_attributesGoogle::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1AndroidAttributes

Resource representing the Android specific attributes of a Device. Corresponds to the JSON property androidSpecificAttributes



2238
2239
2240
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2238

def android_specific_attributes
  @android_specific_attributes
end

#asset_tagString

Asset tag of the device. Corresponds to the JSON property assetTag

Returns:

  • (String)


2243
2244
2245
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2243

def asset_tag
  @asset_tag
end

#baseband_versionString

Output only. Baseband version of the device. Corresponds to the JSON property basebandVersion

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2248

def baseband_version
  @baseband_version
end

#bootloader_versionString

Output only. Device bootloader version. Example: 0.6.7. Corresponds to the JSON property bootloaderVersion

Returns:

  • (String)


2253
2254
2255
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2253

def bootloader_version
  @bootloader_version
end

#brandString

Output only. Device brand. Example: Samsung. Corresponds to the JSON property brand

Returns:

  • (String)


2258
2259
2260
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2258

def brand
  @brand
end

#build_numberString

Output only. Build number of the device. Corresponds to the JSON property buildNumber

Returns:

  • (String)


2263
2264
2265
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2263

def build_number
  @build_number
end

#compromised_stateString

Output only. Represents whether the Device is compromised. Corresponds to the JSON property compromisedState

Returns:

  • (String)


2268
2269
2270
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2268

def compromised_state
  @compromised_state
end

#create_timeString

Output only. When the Company-Owned device was imported. This field is empty for BYOD devices. Corresponds to the JSON property createTime

Returns:

  • (String)


2274
2275
2276
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2274

def create_time
  @create_time
end

#device_idString

Unique identifier for the device. Corresponds to the JSON property deviceId

Returns:

  • (String)


2279
2280
2281
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2279

def device_id
  @device_id
end

#device_typeString

Output only. Type of device. Corresponds to the JSON property deviceType

Returns:

  • (String)


2284
2285
2286
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2284

def device_type
  @device_type
end

#enabled_developer_optionsBoolean Also known as: enabled_developer_options?

Output only. Whether developer options is enabled on device. Corresponds to the JSON property enabledDeveloperOptions

Returns:

  • (Boolean)


2289
2290
2291
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2289

def enabled_developer_options
  @enabled_developer_options
end

#enabled_usb_debuggingBoolean Also known as: enabled_usb_debugging?

Output only. Whether USB debugging is enabled on device. Corresponds to the JSON property enabledUsbDebugging

Returns:

  • (Boolean)


2295
2296
2297
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2295

def enabled_usb_debugging
  @enabled_usb_debugging
end

#encryption_stateString

Output only. Device encryption state. Corresponds to the JSON property encryptionState

Returns:

  • (String)


2301
2302
2303
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2301

def encryption_state
  @encryption_state
end

#endpoint_verification_specific_attributesGoogle::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes

Resource representing the Endpoint Verification-specific attributes of a device. Corresponds to the JSON property endpointVerificationSpecificAttributes



2307
2308
2309
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2307

def endpoint_verification_specific_attributes
  @endpoint_verification_specific_attributes
end

#hostnameString

Host name of the device. Corresponds to the JSON property hostname

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2312

def hostname
  @hostname
end

#imeiString

Output only. IMEI number of device if GSM device; empty otherwise. Corresponds to the JSON property imei

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2317

def imei
  @imei
end

#kernel_versionString

Output only. Kernel version of the device. Corresponds to the JSON property kernelVersion

Returns:

  • (String)


2322
2323
2324
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2322

def kernel_version
  @kernel_version
end

#last_sync_timeString

Most recent time when device synced with this service. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2327

def last_sync_time
  @last_sync_time
end

#management_stateString

Output only. Management state of the device Corresponds to the JSON property managementState

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2332

def management_state
  @management_state
end

#manufacturerString

Output only. Device manufacturer. Example: Motorola. Corresponds to the JSON property manufacturer

Returns:

  • (String)


2337
2338
2339
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2337

def manufacturer
  @manufacturer
end

#meidString

Output only. MEID number of device if CDMA device; empty otherwise. Corresponds to the JSON property meid

Returns:

  • (String)


2342
2343
2344
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2342

def meid
  @meid
end

#modelString

Output only. Model name of device. Example: Pixel 3. Corresponds to the JSON property model

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2347

def model
  @model
end

#nameString

Output only. Resource name of the Device in format: devices/device`, where device is the unique id assigned to the Device. Important: Device API scopes require that you use domain-wide delegation to access the API. For more information, see [Set up the Devices API](https://cloud.google.com/identity/docs/how-to/ setup-devices). Corresponds to the JSON propertyname`

Returns:

  • (String)


2357
2358
2359
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2357

def name
  @name
end

#network_operatorString

Output only. Mobile or network operator of device, if available. Corresponds to the JSON property networkOperator

Returns:

  • (String)


2362
2363
2364
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2362

def network_operator
  @network_operator
end

#os_versionString

Output only. OS version of the device. Example: Android 8.1.0. Corresponds to the JSON property osVersion

Returns:

  • (String)


2367
2368
2369
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2367

def os_version
  @os_version
end

#other_accountsArray<String>

Output only. Domain name for Google accounts on device. Type for other accounts on device. On Android, will only be populated if |ownership_privilege| is |PROFILE_OWNER| or |DEVICE_OWNER|. Does not include the account signed in to the device policy app if that account's domain has only one account. Examples: "com.example", "xyz.com". Corresponds to the JSON property otherAccounts

Returns:

  • (Array<String>)


2376
2377
2378
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2376

def other_accounts
  @other_accounts
end

#owner_typeString

Output only. Whether the device is owned by the company or an individual Corresponds to the JSON property ownerType

Returns:

  • (String)


2381
2382
2383
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2381

def owner_type
  @owner_type
end

#release_versionString

Output only. OS release version. Example: 6.0. Corresponds to the JSON property releaseVersion

Returns:

  • (String)


2386
2387
2388
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2386

def release_version
  @release_version
end

#security_patch_timeString

Output only. OS security patch update time on device. Corresponds to the JSON property securityPatchTime

Returns:

  • (String)


2391
2392
2393
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2391

def security_patch_time
  @security_patch_time
end

#serial_numberString

Serial Number of device. Example: HT82V1A01076. Corresponds to the JSON property serialNumber

Returns:

  • (String)


2396
2397
2398
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2396

def serial_number
  @serial_number
end

#unified_device_idString

Output only. Unified device id of the device. Corresponds to the JSON property unifiedDeviceId

Returns:

  • (String)


2401
2402
2403
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2401

def unified_device_id
  @unified_device_id
end

#wifi_mac_addressesArray<String>

WiFi MAC addresses of device. Corresponds to the JSON property wifiMacAddresses

Returns:

  • (Array<String>)


2406
2407
2408
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2406

def wifi_mac_addresses
  @wifi_mac_addresses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2413

def update!(**args)
  @android_specific_attributes = args[:android_specific_attributes] if args.key?(:android_specific_attributes)
  @asset_tag = args[:asset_tag] if args.key?(:asset_tag)
  @baseband_version = args[:baseband_version] if args.key?(:baseband_version)
  @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version)
  @brand = args[:brand] if args.key?(:brand)
  @build_number = args[:build_number] if args.key?(:build_number)
  @compromised_state = args[:compromised_state] if args.key?(:compromised_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_type = args[:device_type] if args.key?(:device_type)
  @enabled_developer_options = args[:enabled_developer_options] if args.key?(:enabled_developer_options)
  @enabled_usb_debugging = args[:enabled_usb_debugging] if args.key?(:enabled_usb_debugging)
  @encryption_state = args[:encryption_state] if args.key?(:encryption_state)
  @endpoint_verification_specific_attributes = args[:endpoint_verification_specific_attributes] if args.key?(:endpoint_verification_specific_attributes)
  @hostname = args[:hostname] if args.key?(:hostname)
  @imei = args[:imei] if args.key?(:imei)
  @kernel_version = args[:kernel_version] if args.key?(:kernel_version)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @management_state = args[:management_state] if args.key?(:management_state)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @meid = args[:meid] if args.key?(:meid)
  @model = args[:model] if args.key?(:model)
  @name = args[:name] if args.key?(:name)
  @network_operator = args[:network_operator] if args.key?(:network_operator)
  @os_version = args[:os_version] if args.key?(:os_version)
  @other_accounts = args[:other_accounts] if args.key?(:other_accounts)
  @owner_type = args[:owner_type] if args.key?(:owner_type)
  @release_version = args[:release_version] if args.key?(:release_version)
  @security_patch_time = args[:security_patch_time] if args.key?(:security_patch_time)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @unified_device_id = args[:unified_device_id] if args.key?(:unified_device_id)
  @wifi_mac_addresses = args[:wifi_mac_addresses] if args.key?(:wifi_mac_addresses)
end