Class: Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1DeviceUser

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Represents a user's use of a Device in the Cloud Identity Devices API. A DeviceUser is a resource representing a user's use of a Device

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1DeviceUser

Returns a new instance of GoogleAppsCloudidentityDevicesV1DeviceUser.



2480
2481
2482
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compromised_stateString

Compromised State of the DeviceUser object Corresponds to the JSON property compromisedState

Returns:

  • (String)


2430
2431
2432
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2430

def compromised_state
  @compromised_state
end

#create_timeString

When the user first signed in to the device Corresponds to the JSON property createTime

Returns:

  • (String)


2435
2436
2437
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2435

def create_time
  @create_time
end

#first_sync_timeString

Output only. Most recent time when user registered with this service. Corresponds to the JSON property firstSyncTime

Returns:

  • (String)


2440
2441
2442
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2440

def first_sync_time
  @first_sync_time
end

#language_codeString

Output only. Default locale used on device, in IETF BCP-47 format. Corresponds to the JSON property languageCode

Returns:

  • (String)


2445
2446
2447
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2445

def language_code
  @language_code
end

#last_sync_timeString

Output only. Last time when user synced with policies. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2450
2451
2452
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2450

def last_sync_time
  @last_sync_time
end

#management_stateString

Output only. Management state of the user on the device. Corresponds to the JSON property managementState

Returns:

  • (String)


2455
2456
2457
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2455

def management_state
  @management_state
end

#nameString

Output only. Resource name of the DeviceUser in format: devices/device/deviceUsers/ device_user`, wheredevice_useruniquely identifies a user's use of a device. Corresponds to the JSON propertyname`

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2463

def name
  @name
end

#password_stateString

Password state of the DeviceUser object Corresponds to the JSON property passwordState

Returns:

  • (String)


2468
2469
2470
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2468

def password_state
  @password_state
end

#user_agentString

Output only. User agent on the device for this specific user Corresponds to the JSON property userAgent

Returns:

  • (String)


2473
2474
2475
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2473

def user_agent
  @user_agent
end

#user_emailString

Email address of the user registered on the device. Corresponds to the JSON property userEmail

Returns:

  • (String)


2478
2479
2480
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2478

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2485

def update!(**args)
  @compromised_state = args[:compromised_state] if args.key?(:compromised_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @first_sync_time = args[:first_sync_time] if args.key?(:first_sync_time)
  @language_code = args[:language_code] if args.key?(:language_code)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @management_state = args[:management_state] if args.key?(:management_state)
  @name = args[:name] if args.key?(:name)
  @password_state = args[:password_state] if args.key?(:password_state)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @user_email = args[:user_email] if args.key?(:user_email)
end