Class: Google::Apis::CloudidentityV1beta1::GroupRelation
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::GroupRelation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Message representing a transitive group of a user or a group.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Display name for this group.
-
#group ⇒ String
Resource name for this group.
-
#group_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API.
-
#labels ⇒ Hash<String,String>
Labels for Group resource.
-
#relation_type ⇒ String
The relation between the member and the transitive group.
-
#roles ⇒ Array<Google::Apis::CloudidentityV1beta1::TransitiveMembershipRole>
Membership roles of the member for the group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupRelation
constructor
A new instance of GroupRelation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupRelation
Returns a new instance of GroupRelation.
2766 2767 2768 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Display name for this group.
Corresponds to the JSON property displayName
2736 2737 2738 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2736 def display_name @display_name end |
#group ⇒ String
Resource name for this group.
Corresponds to the JSON property group
2741 2742 2743 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2741 def group @group end |
#group_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity
can represent either a group with an optional namespace or a user without a
namespace. The combination of id and namespace must be unique; however,
the same id can be used with different namespaces.
Corresponds to the JSON property groupKey
2749 2750 2751 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2749 def group_key @group_key end |
#labels ⇒ Hash<String,String>
Labels for Group resource.
Corresponds to the JSON property labels
2754 2755 2756 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2754 def labels @labels end |
#relation_type ⇒ String
The relation between the member and the transitive group.
Corresponds to the JSON property relationType
2759 2760 2761 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2759 def relation_type @relation_type end |
#roles ⇒ Array<Google::Apis::CloudidentityV1beta1::TransitiveMembershipRole>
Membership roles of the member for the group.
Corresponds to the JSON property roles
2764 2765 2766 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2764 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2771 2772 2773 2774 2775 2776 2777 2778 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2771 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @group = args[:group] if args.key?(:group) @group_key = args[:group_key] if args.key?(:group_key) @labels = args[:labels] if args.key?(:labels) @relation_type = args[:relation_type] if args.key?(:relation_type) @roles = args[:roles] if args.key?(:roles) end |