Class: Google::Apis::CloudidentityV1beta1::InboundSsoAssignment
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::InboundSsoAssignment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Targets with "set" SSO assignments and their respective assignments.
Instance Attribute Summary collapse
-
#customer ⇒ String
Immutable.
-
#name ⇒ String
Output only.
-
#oidc_sso_info ⇒ Google::Apis::CloudidentityV1beta1::OidcSsoInfo
Details that are applicable when
sso_modeis set toOIDC_SSO. -
#rank ⇒ Fixnum
Must be zero (which is the default value so it can be omitted) for assignments with
target_org_unitset and must be greater-than-or-equal-to one for assignments withtarget_groupset. -
#saml_sso_info ⇒ Google::Apis::CloudidentityV1beta1::SamlSsoInfo
Details that are applicable when
sso_mode==SAML_SSO. -
#sign_in_behavior ⇒ Google::Apis::CloudidentityV1beta1::SignInBehavior
Controls sign-in behavior.
-
#sso_mode ⇒ String
Inbound SSO behavior.
-
#target_group ⇒ String
Immutable.
-
#target_org_unit ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InboundSsoAssignment
constructor
A new instance of InboundSsoAssignment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InboundSsoAssignment
Returns a new instance of InboundSsoAssignment.
2846 2847 2848 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
Immutable. The customer. For example: customers/C0123abc.
Corresponds to the JSON property customer
2801 2802 2803 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2801 def customer @customer end |
#name ⇒ String
Output only. Resource name of the Inbound SSO Assignment.
Corresponds to the JSON property name
2807 2808 2809 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2807 def name @name end |
#oidc_sso_info ⇒ Google::Apis::CloudidentityV1beta1::OidcSsoInfo
Details that are applicable when sso_mode is set to OIDC_SSO.
Corresponds to the JSON property oidcSsoInfo
2812 2813 2814 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2812 def oidc_sso_info @oidc_sso_info end |
#rank ⇒ Fixnum
Must be zero (which is the default value so it can be omitted) for assignments
with target_org_unit set and must be greater-than-or-equal-to one for
assignments with target_group set.
Corresponds to the JSON property rank
2819 2820 2821 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2819 def rank @rank end |
#saml_sso_info ⇒ Google::Apis::CloudidentityV1beta1::SamlSsoInfo
Details that are applicable when sso_mode == SAML_SSO.
Corresponds to the JSON property samlSsoInfo
2824 2825 2826 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2824 def saml_sso_info @saml_sso_info end |
#sign_in_behavior ⇒ Google::Apis::CloudidentityV1beta1::SignInBehavior
Controls sign-in behavior.
Corresponds to the JSON property signInBehavior
2829 2830 2831 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2829 def sign_in_behavior @sign_in_behavior end |
#sso_mode ⇒ String
Inbound SSO behavior.
Corresponds to the JSON property ssoMode
2834 2835 2836 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2834 def sso_mode @sso_mode end |
#target_group ⇒ String
Immutable. Must be of the form groups/group`.
Corresponds to the JSON propertytargetGroup`
2839 2840 2841 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2839 def target_group @target_group end |
#target_org_unit ⇒ String
Immutable. Must be of the form orgUnits/org_unit`.
Corresponds to the JSON propertytargetOrgUnit`
2844 2845 2846 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2844 def target_org_unit @target_org_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2851 def update!(**args) @customer = args[:customer] if args.key?(:customer) @name = args[:name] if args.key?(:name) @oidc_sso_info = args[:oidc_sso_info] if args.key?(:oidc_sso_info) @rank = args[:rank] if args.key?(:rank) @saml_sso_info = args[:saml_sso_info] if args.key?(:saml_sso_info) @sign_in_behavior = args[:sign_in_behavior] if args.key?(:sign_in_behavior) @sso_mode = args[:sso_mode] if args.key?(:sso_mode) @target_group = args[:target_group] if args.key?(:target_group) @target_org_unit = args[:target_org_unit] if args.key?(:target_org_unit) end |