Class: Google::Apis::CloudidentityV1beta1::ListGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

The response message for GroupsService.ListGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGroupsResponse

Returns a new instance of ListGroupsResponse.



3182
3183
3184
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupsArray<Google::Apis::CloudidentityV1beta1::Group>

The Group resources under the specified parent. Corresponds to the JSON property groups



3174
3175
3176
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3174

def groups
  @groups
end

#next_page_tokenString

A continuation token to retrieve the next page of results, or empty if there are no more results available. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3180
3181
3182
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3180

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3187
3188
3189
3190
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3187

def update!(**args)
  @groups = args[:groups] if args.key?(:groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end