Class: Google::Apis::CloudidentityV1beta1::Membership
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::Membership
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
A membership within the Cloud Identity Groups API. A Membership defines a
relationship between a Group and an entity belonging to that Group,
referred to as a "member".
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delivery_setting ⇒ String
Output only.
-
#member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API.
-
#name ⇒ String
Output only.
-
#preferred_member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API.
-
#roles ⇒ Array<Google::Apis::CloudidentityV1beta1::MembershipRole>
The
MembershipRoles that apply to theMembership. -
#type ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Membership
constructor
A new instance of Membership.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Membership
Returns a new instance of Membership.
3555 3556 3557 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the Membership was created.
Corresponds to the JSON property createTime
3508 3509 3510 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3508 def create_time @create_time end |
#delivery_setting ⇒ String
Output only. Delivery setting associated with the membership.
Corresponds to the JSON property deliverySetting
3513 3514 3515 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3513 def delivery_setting @delivery_setting end |
#member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity
can represent either a group with an optional namespace or a user without a
namespace. The combination of id and namespace must be unique; however,
the same id can be used with different namespaces.
Corresponds to the JSON property memberKey
3521 3522 3523 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3521 def member_key @member_key end |
#name ⇒ String
Output only. The resource name of the Membership. Shall be of the form groups/group_id/
memberships/membership_id`.
Corresponds to the JSON propertyname`
3528 3529 3530 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3528 def name @name end |
#preferred_member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity
can represent either a group with an optional namespace or a user without a
namespace. The combination of id and namespace must be unique; however,
the same id can be used with different namespaces.
Corresponds to the JSON property preferredMemberKey
3536 3537 3538 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3536 def preferred_member_key @preferred_member_key end |
#roles ⇒ Array<Google::Apis::CloudidentityV1beta1::MembershipRole>
The MembershipRoles that apply to the Membership. If unspecified, defaults
to a single MembershipRole with name MEMBER. Must not contain duplicate
MembershipRoles with the same name.
Corresponds to the JSON property roles
3543 3544 3545 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3543 def roles @roles end |
#type ⇒ String
Output only. The type of the membership.
Corresponds to the JSON property type
3548 3549 3550 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3548 def type @type end |
#update_time ⇒ String
Output only. The time when the Membership was last updated.
Corresponds to the JSON property updateTime
3553 3554 3555 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3553 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3560 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delivery_setting = args[:delivery_setting] if args.key?(:delivery_setting) @member_key = args[:member_key] if args.key?(:member_key) @name = args[:name] if args.key?(:name) @preferred_member_key = args[:preferred_member_key] if args.key?(:preferred_member_key) @roles = args[:roles] if args.key?(:roles) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |