Class: Google::Apis::CloudidentityV1beta1::MembershipRole

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

A membership role within the Cloud Identity Groups API. A MembershipRole defines the privileges granted to a Membership.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipRole

Returns a new instance of MembershipRole.



3736
3737
3738
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expiry_detailGoogle::Apis::CloudidentityV1beta1::ExpiryDetail

The MembershipRole expiry details. Corresponds to the JSON property expiryDetail



3724
3725
3726
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3724

def expiry_detail
  @expiry_detail
end

#nameString

The name of the MembershipRole. Must be one of OWNER, MANAGER, MEMBER. Corresponds to the JSON property name

Returns:

  • (String)


3729
3730
3731
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3729

def name
  @name
end

#restriction_evaluationsGoogle::Apis::CloudidentityV1beta1::RestrictionEvaluations

Evaluations of restrictions applied to parent group on this membership. Corresponds to the JSON property restrictionEvaluations



3734
3735
3736
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3734

def restriction_evaluations
  @restriction_evaluations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3741
3742
3743
3744
3745
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3741

def update!(**args)
  @expiry_detail = args[:expiry_detail] if args.key?(:expiry_detail)
  @name = args[:name] if args.key?(:name)
  @restriction_evaluations = args[:restriction_evaluations] if args.key?(:restriction_evaluations)
end