Class: Google::Apis::CloudidentityV1beta1::Policy
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::Policy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
A Policy resource binds an instance of a single Setting with the scope of a PolicyQuery. The Setting instance will be applied to all entities that satisfy the query.
Instance Attribute Summary collapse
-
#customer ⇒ String
Immutable.
-
#name ⇒ String
Output only.
-
#policy_query ⇒ Google::Apis::CloudidentityV1beta1::PolicyQuery
PolicyQuery Corresponds to the JSON property
policyQuery. -
#setting ⇒ Google::Apis::CloudidentityV1beta1::Setting
Setting Corresponds to the JSON property
setting. -
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Policy
constructor
A new instance of Policy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Policy
Returns a new instance of Policy.
4037 4038 4039 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
Immutable. Customer that the Policy belongs to. The value is in the format '
customers/customerId'. The customerId must begin with "C" To find your
customer ID in Admin Console see https://support.google.com/a/answer/10070793.
Corresponds to the JSON property customer
4014 4015 4016 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4014 def customer @customer end |
#name ⇒ String
Output only. Identifier. The resource name of the Policy. Format: policies/policy.
Corresponds to the JSON property name
4020 4021 4022 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4020 def name @name end |
#policy_query ⇒ Google::Apis::CloudidentityV1beta1::PolicyQuery
PolicyQuery
Corresponds to the JSON property policyQuery
4025 4026 4027 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4025 def policy_query @policy_query end |
#setting ⇒ Google::Apis::CloudidentityV1beta1::Setting
Setting
Corresponds to the JSON property setting
4030 4031 4032 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4030 def setting @setting end |
#type ⇒ String
Output only. The type of the policy.
Corresponds to the JSON property type
4035 4036 4037 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4035 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4042 4043 4044 4045 4046 4047 4048 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4042 def update!(**args) @customer = args[:customer] if args.key?(:customer) @name = args[:name] if args.key?(:name) @policy_query = args[:policy_query] if args.key?(:policy_query) @setting = args[:setting] if args.key?(:setting) @type = args[:type] if args.key?(:type) end |