Class: Google::Apis::CloudidentityV1beta1::PosixGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

POSIX Group definition to represent a group in a POSIX compliant system. Caution: POSIX groups are deprecated. As of September 26, 2024, you can no longer create new POSIX groups. For more information, see https://cloud.google. com/identity/docs/deprecations/posix-groups

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PosixGroup

Returns a new instance of PosixGroup.



4122
4123
4124
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gidFixnum

GID of the POSIX group. Corresponds to the JSON property gid

Returns:

  • (Fixnum)


4109
4110
4111
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4109

def gid
  @gid
end

#nameString

Name of the POSIX group. Corresponds to the JSON property name

Returns:

  • (String)


4114
4115
4116
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4114

def name
  @name
end

#system_idString

System identifier for which group name and gid apply to. If not specified it will default to empty value. Corresponds to the JSON property systemId

Returns:

  • (String)


4120
4121
4122
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4120

def system_id
  @system_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4127
4128
4129
4130
4131
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4127

def update!(**args)
  @gid = args[:gid] if args.key?(:gid)
  @name = args[:name] if args.key?(:name)
  @system_id = args[:system_id] if args.key?(:system_id)
end