Class: Google::Apis::CloudidentityV1beta1::SearchDirectGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

The response message for MembershipsService.SearchDirectGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchDirectGroupsResponse

Returns a new instance of SearchDirectGroupsResponse.



4298
4299
4300
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipsArray<Google::Apis::CloudidentityV1beta1::MembershipRelation>

List of direct groups satisfying the query. Corresponds to the JSON property memberships



4290
4291
4292
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4290

def memberships
  @memberships
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results available for listing. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4296
4297
4298
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4296

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4303
4304
4305
4306
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4303

def update!(**args)
  @memberships = args[:memberships] if args.key?(:memberships)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end