Class: Google::Apis::CloudidentityV1beta1::SearchTransitiveGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::SearchTransitiveGroupsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
The response message for MembershipsService.SearchTransitiveGroups.
Instance Attribute Summary collapse
-
#memberships ⇒ Array<Google::Apis::CloudidentityV1beta1::GroupRelation>
List of transitive groups satisfying the query.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results available for listing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchTransitiveGroupsResponse
constructor
A new instance of SearchTransitiveGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchTransitiveGroupsResponse
Returns a new instance of SearchTransitiveGroupsResponse.
4351 4352 4353 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memberships ⇒ Array<Google::Apis::CloudidentityV1beta1::GroupRelation>
List of transitive groups satisfying the query.
Corresponds to the JSON property memberships
4343 4344 4345 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4343 def memberships @memberships end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results available for listing.
Corresponds to the JSON property nextPageToken
4349 4350 4351 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4349 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4356 4357 4358 4359 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4356 def update!(**args) @memberships = args[:memberships] if args.key?(:memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |