Class: Google::Apis::CloudidentityV1beta1::SearchTransitiveMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::SearchTransitiveMembershipsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
The response message for MembershipsService.SearchTransitiveMemberships.
Instance Attribute Summary collapse
-
#memberships ⇒ Array<Google::Apis::CloudidentityV1beta1::MemberRelation>
List of transitive memberships satisfying the query.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchTransitiveMembershipsResponse
constructor
A new instance of SearchTransitiveMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchTransitiveMembershipsResponse
Returns a new instance of SearchTransitiveMembershipsResponse.
4376 4377 4378 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memberships ⇒ Array<Google::Apis::CloudidentityV1beta1::MemberRelation>
List of transitive memberships satisfying the query.
Corresponds to the JSON property memberships
4368 4369 4370 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4368 def memberships @memberships end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results.
Corresponds to the JSON property nextPageToken
4374 4375 4376 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4374 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4381 4382 4383 4384 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4381 def update!(**args) @memberships = args[:memberships] if args.key?(:memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |