Class: Google::Apis::CloudidentityV1beta1::UpdateMembershipRolesParams
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::UpdateMembershipRolesParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
The details of an update to a MembershipRole.
Instance Attribute Summary collapse
-
#field_mask ⇒ String
The fully-qualified names of fields to update.
-
#membership_role ⇒ Google::Apis::CloudidentityV1beta1::MembershipRole
A membership role within the Cloud Identity Groups API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateMembershipRolesParams
constructor
A new instance of UpdateMembershipRolesParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateMembershipRolesParams
Returns a new instance of UpdateMembershipRolesParams.
4605 4606 4607 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_mask ⇒ String
The fully-qualified names of fields to update. May only contain the field
expiry_detail.expire_time.
Corresponds to the JSON property fieldMask
4597 4598 4599 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4597 def field_mask @field_mask end |
#membership_role ⇒ Google::Apis::CloudidentityV1beta1::MembershipRole
A membership role within the Cloud Identity Groups API. A MembershipRole
defines the privileges granted to a Membership.
Corresponds to the JSON property membershipRole
4603 4604 4605 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4603 def membership_role @membership_role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4610 4611 4612 4613 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4610 def update!(**args) @field_mask = args[:field_mask] if args.key?(:field_mask) @membership_role = args[:membership_role] if args.key?(:membership_role) end |