Class: Google::Apis::CloudidentityV1beta1::UserInvitation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

The UserInvitation resource represents an email that can be sent to an unmanaged user account inviting them to join the customer's Google Workspace or Cloud Identity account. An unmanaged account shares an email address domain with the Google Workspace or Cloud Identity account but is not managed by it yet. If the user accepts the UserInvitation, the user account will become managed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserInvitation

Returns a new instance of UserInvitation.



4739
4740
4741
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mails_sent_countFixnum

Number of invitation emails sent to the user. Corresponds to the JSON property mailsSentCount

Returns:

  • (Fixnum)


4721
4722
4723
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4721

def mails_sent_count
  @mails_sent_count
end

#nameString

Shall be of the form customers/customer/userinvitations/user_email_address . Corresponds to the JSON property name

Returns:

  • (String)


4727
4728
4729
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4727

def name
  @name
end

#stateString

State of the UserInvitation. Corresponds to the JSON property state

Returns:

  • (String)


4732
4733
4734
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4732

def state
  @state
end

#update_timeString

Time when the UserInvitation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4737
4738
4739
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4737

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4744
4745
4746
4747
4748
4749
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4744

def update!(**args)
  @mails_sent_count = args[:mails_sent_count] if args.key?(:mails_sent_count)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end