Class: Google::Apis::CloudidentityV1beta1::WipeDeviceRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::WipeDeviceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Request message for wiping all data on the device.
Instance Attribute Summary collapse
-
#customer ⇒ String
Optional.
-
#remove_reset_lock ⇒ Boolean
(also: #remove_reset_lock?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WipeDeviceRequest
constructor
A new instance of WipeDeviceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WipeDeviceRequest
Returns a new instance of WipeDeviceRequest.
4760 4761 4762 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
Optional. Resource name
of the customer. If you're using this API for your own organization, use
customers/my_customer If you're using this API to manage another organization,
use customers/customer_id`, where customer_id is the customer to whom the
device belongs.
Corresponds to the JSON propertycustomer`
4748 4749 4750 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4748 def customer @customer end |
#remove_reset_lock ⇒ Boolean Also known as: remove_reset_lock?
Optional. Specifies if a user is able to factory reset a device after a Device
Wipe. On iOS, this is called "Activation Lock", while on Android, this is
known as "Factory Reset Protection". If true, this protection will be removed
from the device, so that a user can successfully factory reset. If false, the
setting is untouched on the device.
Corresponds to the JSON property removeResetLock
4757 4758 4759 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4757 def remove_reset_lock @remove_reset_lock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4765 4766 4767 4768 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4765 def update!(**args) @customer = args[:customer] if args.key?(:customer) @remove_reset_lock = args[:remove_reset_lock] if args.key?(:remove_reset_lock) end |