Class: Google::Apis::CloudidentityV1beta1::BrowserInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Browser-specific fields reported by clients on the device, such as Endpoint Verification extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BrowserInfo

Returns a new instance of BrowserInfo.



404
405
406
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#browser_management_stateString

Output only. Browser's management state. Corresponds to the JSON property browserManagementState

Returns:

  • (String)


302
303
304
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 302

def browser_management_state
  @browser_management_state
end

#browser_versionString

Version of the request initiating browser. E.g. 91.0.4442.4. Corresponds to the JSON property browserVersion

Returns:

  • (String)


307
308
309
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 307

def browser_version
  @browser_version
end

#is_built_in_dns_client_enabledBoolean Also known as: is_built_in_dns_client_enabled?

Current state of built-in DNS client. Corresponds to the JSON property isBuiltInDnsClientEnabled

Returns:

  • (Boolean)


313
314
315
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 313

def is_built_in_dns_client_enabled
  @is_built_in_dns_client_enabled
end

#is_bulk_data_entry_analysis_enabledBoolean Also known as: is_bulk_data_entry_analysis_enabled?

Current state of [bulk data analysis](https://chromeenterprise.google/policies/

OnBulkDataEntryEnterpriseConnector). Set to true if provider list from Chrome

is non-empty. Corresponds to the JSON property isBulkDataEntryAnalysisEnabled

Returns:

  • (Boolean)


321
322
323
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 321

def is_bulk_data_entry_analysis_enabled
  @is_bulk_data_entry_analysis_enabled
end

#is_chrome_cleanup_enabledBoolean Also known as: is_chrome_cleanup_enabled?

Deprecated: This field is not used for Chrome version 118 and later. Current state of Chrome Cleanup. Corresponds to the JSON property isChromeCleanupEnabled

Returns:

  • (Boolean)


329
330
331
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 329

def is_chrome_cleanup_enabled
  @is_chrome_cleanup_enabled
end

#is_chrome_remote_desktop_app_blockedBoolean Also known as: is_chrome_remote_desktop_app_blocked?

Current state of Chrome Remote Desktop app. Corresponds to the JSON property isChromeRemoteDesktopAppBlocked

Returns:

  • (Boolean)


336
337
338
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 336

def is_chrome_remote_desktop_app_blocked
  @is_chrome_remote_desktop_app_blocked
end

#is_file_download_analysis_enabledBoolean Also known as: is_file_download_analysis_enabled?

Current state of file download analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isFileDownloadAnalysisEnabled

Returns:

  • (Boolean)


344
345
346
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 344

def is_file_download_analysis_enabled
  @is_file_download_analysis_enabled
end

#is_file_upload_analysis_enabledBoolean Also known as: is_file_upload_analysis_enabled?

Current state of file upload analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isFileUploadAnalysisEnabled

Returns:

  • (Boolean)


352
353
354
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 352

def is_file_upload_analysis_enabled
  @is_file_upload_analysis_enabled
end

#is_realtime_url_check_enabledBoolean Also known as: is_realtime_url_check_enabled?

Current state of real-time URL check. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isRealtimeUrlCheckEnabled

Returns:

  • (Boolean)


360
361
362
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 360

def is_realtime_url_check_enabled
  @is_realtime_url_check_enabled
end

#is_security_event_analysis_enabledBoolean Also known as: is_security_event_analysis_enabled?

Current state of security event analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isSecurityEventAnalysisEnabled

Returns:

  • (Boolean)


368
369
370
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 368

def is_security_event_analysis_enabled
  @is_security_event_analysis_enabled
end

#is_site_isolation_enabledBoolean Also known as: is_site_isolation_enabled?

Current state of site isolation. Corresponds to the JSON property isSiteIsolationEnabled

Returns:

  • (Boolean)


375
376
377
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 375

def is_site_isolation_enabled
  @is_site_isolation_enabled
end

#is_third_party_blocking_enabledBoolean Also known as: is_third_party_blocking_enabled?

Current state of third-party blocking. Corresponds to the JSON property isThirdPartyBlockingEnabled

Returns:

  • (Boolean)


382
383
384
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 382

def is_third_party_blocking_enabled
  @is_third_party_blocking_enabled
end

#password_protection_warning_triggerString

Current state of password protection trigger. Corresponds to the JSON property passwordProtectionWarningTrigger

Returns:

  • (String)


389
390
391
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 389

def password_protection_warning_trigger
  @password_protection_warning_trigger
end

#policiesArray<Google::Apis::CloudidentityV1beta1::ChromePolicy>

Output only. Chrome policies information for the browser as can be seen in chrome://policy. Full possibilities of policies can be consulted in Chrome Enterprise Policy List. Corresponds to the JSON property policies



396
397
398
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 396

def policies
  @policies
end

#safe_browsing_protection_levelString

Current state of Safe Browsing protection level. Corresponds to the JSON property safeBrowsingProtectionLevel

Returns:

  • (String)


402
403
404
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 402

def safe_browsing_protection_level
  @safe_browsing_protection_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 409

def update!(**args)
  @browser_management_state = args[:browser_management_state] if args.key?(:browser_management_state)
  @browser_version = args[:browser_version] if args.key?(:browser_version)
  @is_built_in_dns_client_enabled = args[:is_built_in_dns_client_enabled] if args.key?(:is_built_in_dns_client_enabled)
  @is_bulk_data_entry_analysis_enabled = args[:is_bulk_data_entry_analysis_enabled] if args.key?(:is_bulk_data_entry_analysis_enabled)
  @is_chrome_cleanup_enabled = args[:is_chrome_cleanup_enabled] if args.key?(:is_chrome_cleanup_enabled)
  @is_chrome_remote_desktop_app_blocked = args[:is_chrome_remote_desktop_app_blocked] if args.key?(:is_chrome_remote_desktop_app_blocked)
  @is_file_download_analysis_enabled = args[:is_file_download_analysis_enabled] if args.key?(:is_file_download_analysis_enabled)
  @is_file_upload_analysis_enabled = args[:is_file_upload_analysis_enabled] if args.key?(:is_file_upload_analysis_enabled)
  @is_realtime_url_check_enabled = args[:is_realtime_url_check_enabled] if args.key?(:is_realtime_url_check_enabled)
  @is_security_event_analysis_enabled = args[:is_security_event_analysis_enabled] if args.key?(:is_security_event_analysis_enabled)
  @is_site_isolation_enabled = args[:is_site_isolation_enabled] if args.key?(:is_site_isolation_enabled)
  @is_third_party_blocking_enabled = args[:is_third_party_blocking_enabled] if args.key?(:is_third_party_blocking_enabled)
  @password_protection_warning_trigger = args[:password_protection_warning_trigger] if args.key?(:password_protection_warning_trigger)
  @policies = args[:policies] if args.key?(:policies)
  @safe_browsing_protection_level = args[:safe_browsing_protection_level] if args.key?(:safe_browsing_protection_level)
end