Class: Google::Apis::CloudidentityV1beta1::ClientState
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::ClientState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Represents the state associated with an API client calling the Devices API. Resource representing ClientState and supports updates from API users
Instance Attribute Summary collapse
-
#asset_tags ⇒ Array<String>
The caller can specify asset tags for this resource Corresponds to the JSON property
assetTags. -
#compliance_state ⇒ String
The compliance state of the resource as specified by the API client.
-
#create_time ⇒ String
Output only.
-
#custom_id ⇒ String
This field may be used to store a unique identifier for the API resource within which these CustomAttributes are a field.
-
#etag ⇒ String
The token that needs to be passed back for concurrency control in updates.
-
#health_score ⇒ String
The Health score of the resource Corresponds to the JSON property
healthScore. -
#key_value_pairs ⇒ Hash<String,Google::Apis::CloudidentityV1beta1::CustomAttributeValue>
The map of key-value attributes stored by callers specific to a device.
-
#last_update_time ⇒ String
Output only.
-
#managed ⇒ String
The management state of the resource as specified by the API client.
-
#name ⇒ String
Output only.
-
#owner_type ⇒ String
Output only.
-
#score_reason ⇒ String
A descriptive cause of the health score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientState
constructor
A new instance of ClientState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientState
Returns a new instance of ClientState.
801 802 803 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_tags ⇒ Array<String>
The caller can specify asset tags for this resource
Corresponds to the JSON property assetTags
737 738 739 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 737 def @asset_tags end |
#compliance_state ⇒ String
The compliance state of the resource as specified by the API client.
Corresponds to the JSON property complianceState
742 743 744 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 742 def compliance_state @compliance_state end |
#create_time ⇒ String
Output only. The time the client state data was created.
Corresponds to the JSON property createTime
747 748 749 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 747 def create_time @create_time end |
#custom_id ⇒ String
This field may be used to store a unique identifier for the API resource
within which these CustomAttributes are a field.
Corresponds to the JSON property customId
753 754 755 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 753 def custom_id @custom_id end |
#etag ⇒ String
The token that needs to be passed back for concurrency control in updates.
Token needs to be passed back in UpdateRequest
Corresponds to the JSON property etag
759 760 761 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 759 def etag @etag end |
#health_score ⇒ String
The Health score of the resource
Corresponds to the JSON property healthScore
764 765 766 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 764 def health_score @health_score end |
#key_value_pairs ⇒ Hash<String,Google::Apis::CloudidentityV1beta1::CustomAttributeValue>
The map of key-value attributes stored by callers specific to a device. The
total serialized length of this map may not exceed 10KB. No limit is placed on
the number of attributes in a map.
Corresponds to the JSON property keyValuePairs
771 772 773 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 771 def key_value_pairs @key_value_pairs end |
#last_update_time ⇒ String
Output only. The time the client state data was last updated.
Corresponds to the JSON property lastUpdateTime
776 777 778 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 776 def last_update_time @last_update_time end |
#managed ⇒ String
The management state of the resource as specified by the API client.
Corresponds to the JSON property managed
781 782 783 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 781 def managed @managed end |
#name ⇒ String
Output only. Resource name of the ClientState in format: devices/device_id/deviceUsers/
device_user_id/clientState/partner_id`, where partner_id corresponds to
the partner storing the data.
Corresponds to the JSON propertyname`
789 790 791 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 789 def name @name end |
#owner_type ⇒ String
Output only. The owner of the ClientState
Corresponds to the JSON property ownerType
794 795 796 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 794 def owner_type @owner_type end |
#score_reason ⇒ String
A descriptive cause of the health score.
Corresponds to the JSON property scoreReason
799 800 801 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 799 def score_reason @score_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 806 def update!(**args) @asset_tags = args[:asset_tags] if args.key?(:asset_tags) @compliance_state = args[:compliance_state] if args.key?(:compliance_state) @create_time = args[:create_time] if args.key?(:create_time) @custom_id = args[:custom_id] if args.key?(:custom_id) @etag = args[:etag] if args.key?(:etag) @health_score = args[:health_score] if args.key?(:health_score) @key_value_pairs = args[:key_value_pairs] if args.key?(:key_value_pairs) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @managed = args[:managed] if args.key?(:managed) @name = args[:name] if args.key?(:name) @owner_type = args[:owner_type] if args.key?(:owner_type) @score_reason = args[:score_reason] if args.key?(:score_reason) end |