Class: Google::Apis::CloudidentityV1beta1::Device
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::Device
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
A Device within the Cloud Identity Devices API. Represents a Device known to Google Cloud, independent of the device ownership, type, and whether it is assigned or in use by a user. Important: Device API scopes require that you use domain-wide delegation to access the API. For more information, see Set up the Devices API.
Instance Attribute Summary collapse
-
#android_specific_attributes ⇒ Google::Apis::CloudidentityV1beta1::AndroidAttributes
Resource representing the Android specific attributes of a Device.
-
#antivirus_info ⇒ Array<Google::Apis::CloudidentityV1beta1::AntivirusInfo>
Output only.
-
#asset_tag ⇒ String
Asset tag of the device.
-
#baseband_version ⇒ String
Output only.
-
#bootloader_version ⇒ String
Output only.
-
#brand ⇒ String
Output only.
-
#browser_profiles ⇒ Array<Google::Apis::CloudidentityV1beta1::BrowserAttributes>
Browser profiles on the device.
-
#build_number ⇒ String
Output only.
-
#client_types ⇒ Array<String>
List of the clients the device is reporting to.
-
#compromised_state ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#device_id ⇒ String
Unique identifier for the device.
-
#device_type ⇒ String
Output only.
-
#enabled_developer_options ⇒ Boolean
(also: #enabled_developer_options?)
Output only.
-
#enabled_usb_debugging ⇒ Boolean
(also: #enabled_usb_debugging?)
Output only.
-
#encryption_state ⇒ String
Output only.
-
#endpoint_verification_specific_attributes ⇒ Google::Apis::CloudidentityV1beta1::EndpointVerificationSpecificAttributes
Resource representing the Endpoint Verification-specific attributes of a device.
-
#hostname ⇒ String
Host name of the device.
-
#imei ⇒ String
Output only.
-
#kernel_version ⇒ String
Output only.
-
#last_sync_time ⇒ String
Most recent time when device synced with this service.
-
#management_state ⇒ String
Output only.
-
#manufacturer ⇒ String
Output only.
-
#meid ⇒ String
Output only.
-
#model ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#network_operator ⇒ String
Output only.
-
#os_firewall_status ⇒ String
Output only.
-
#os_version ⇒ String
Output only.
-
#other_accounts ⇒ Array<String>
Output only.
-
#owner_type ⇒ String
Output only.
-
#release_version ⇒ String
Output only.
-
#security_patch_time ⇒ String
Output only.
-
#serial_number ⇒ String
Serial Number of device.
-
#unified_device_id ⇒ String
Output only.
-
#wifi_mac_addresses ⇒ Array<String>
WiFi MAC addresses of device.
-
#windows_specific_device_attributes ⇒ Google::Apis::CloudidentityV1beta1::WindowsSpecificDeviceAttributes
Represents the Windows specific attributes of a Device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Device
constructor
A new instance of Device.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Device
Returns a new instance of Device.
1181 1182 1183 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_specific_attributes ⇒ Google::Apis::CloudidentityV1beta1::AndroidAttributes
Resource representing the Android specific attributes of a Device.
Corresponds to the JSON property androidSpecificAttributes
986 987 988 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 986 def android_specific_attributes @android_specific_attributes end |
#antivirus_info ⇒ Array<Google::Apis::CloudidentityV1beta1::AntivirusInfo>
Output only. Anti-virus information for the device.
Corresponds to the JSON property antivirusInfo
991 992 993 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 991 def antivirus_info @antivirus_info end |
#asset_tag ⇒ String
Asset tag of the device.
Corresponds to the JSON property assetTag
996 997 998 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 996 def asset_tag @asset_tag end |
#baseband_version ⇒ String
Output only. Baseband version of the device.
Corresponds to the JSON property basebandVersion
1001 1002 1003 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1001 def baseband_version @baseband_version end |
#bootloader_version ⇒ String
Output only. Device bootloader version. Example: 0.6.7.
Corresponds to the JSON property bootloaderVersion
1006 1007 1008 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1006 def bootloader_version @bootloader_version end |
#brand ⇒ String
Output only. Device brand. Example: Samsung.
Corresponds to the JSON property brand
1011 1012 1013 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1011 def brand @brand end |
#browser_profiles ⇒ Array<Google::Apis::CloudidentityV1beta1::BrowserAttributes>
Browser profiles on the device. This is a copy of the BrowserAttributes
message defined in EndpointVerificationSpecificAttributes. We are replicating
it here since EndpointVerification isn't the only client reporting browser
profiles.
Corresponds to the JSON property browserProfiles
1019 1020 1021 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1019 def browser_profiles @browser_profiles end |
#build_number ⇒ String
Output only. Build number of the device.
Corresponds to the JSON property buildNumber
1024 1025 1026 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1024 def build_number @build_number end |
#client_types ⇒ Array<String>
List of the clients the device is reporting to.
Corresponds to the JSON property clientTypes
1029 1030 1031 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1029 def client_types @client_types end |
#compromised_state ⇒ String
Output only. Represents whether the Device is compromised.
Corresponds to the JSON property compromisedState
1034 1035 1036 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1034 def compromised_state @compromised_state end |
#create_time ⇒ String
Output only. When the Company-Owned device was imported. This field is empty
for BYOD devices.
Corresponds to the JSON property createTime
1040 1041 1042 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1040 def create_time @create_time end |
#device_id ⇒ String
Unique identifier for the device.
Corresponds to the JSON property deviceId
1045 1046 1047 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1045 def device_id @device_id end |
#device_type ⇒ String
Output only. Type of device.
Corresponds to the JSON property deviceType
1050 1051 1052 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1050 def device_type @device_type end |
#enabled_developer_options ⇒ Boolean Also known as: enabled_developer_options?
Output only. Whether developer options is enabled on device.
Corresponds to the JSON property enabledDeveloperOptions
1055 1056 1057 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1055 def @enabled_developer_options end |
#enabled_usb_debugging ⇒ Boolean Also known as: enabled_usb_debugging?
Output only. Whether USB debugging is enabled on device.
Corresponds to the JSON property enabledUsbDebugging
1061 1062 1063 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1061 def enabled_usb_debugging @enabled_usb_debugging end |
#encryption_state ⇒ String
Output only. Device encryption state.
Corresponds to the JSON property encryptionState
1067 1068 1069 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1067 def encryption_state @encryption_state end |
#endpoint_verification_specific_attributes ⇒ Google::Apis::CloudidentityV1beta1::EndpointVerificationSpecificAttributes
Resource representing the Endpoint Verification-specific attributes of a device.
Corresponds to the JSON property endpointVerificationSpecificAttributes
1073 1074 1075 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1073 def endpoint_verification_specific_attributes @endpoint_verification_specific_attributes end |
#hostname ⇒ String
Host name of the device.
Corresponds to the JSON property hostname
1078 1079 1080 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1078 def hostname @hostname end |
#imei ⇒ String
Output only. IMEI number of device if GSM device; empty otherwise.
Corresponds to the JSON property imei
1083 1084 1085 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1083 def imei @imei end |
#kernel_version ⇒ String
Output only. Kernel version of the device.
Corresponds to the JSON property kernelVersion
1088 1089 1090 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1088 def kernel_version @kernel_version end |
#last_sync_time ⇒ String
Most recent time when device synced with this service.
Corresponds to the JSON property lastSyncTime
1093 1094 1095 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1093 def last_sync_time @last_sync_time end |
#management_state ⇒ String
Output only. Management state of the device
Corresponds to the JSON property managementState
1098 1099 1100 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1098 def management_state @management_state end |
#manufacturer ⇒ String
Output only. Device manufacturer. Example: Motorola.
Corresponds to the JSON property manufacturer
1103 1104 1105 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1103 def manufacturer @manufacturer end |
#meid ⇒ String
Output only. MEID number of device if CDMA device; empty otherwise.
Corresponds to the JSON property meid
1108 1109 1110 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1108 def meid @meid end |
#model ⇒ String
Output only. Model name of device. Example: Pixel 3.
Corresponds to the JSON property model
1113 1114 1115 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1113 def model @model end |
#name ⇒ String
Output only. Resource name of the Device in format: devices/device_id`, where
device_id is the unique id assigned to the Device.
Corresponds to the JSON propertyname`
1120 1121 1122 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1120 def name @name end |
#network_operator ⇒ String
Output only. Mobile or network operator of device, if available.
Corresponds to the JSON property networkOperator
1125 1126 1127 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1125 def network_operator @network_operator end |
#os_firewall_status ⇒ String
Output only. OS firewall status of the device.
Corresponds to the JSON property osFirewallStatus
1130 1131 1132 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1130 def os_firewall_status @os_firewall_status end |
#os_version ⇒ String
Output only. OS version of the device. Example: Android 8.1.0.
Corresponds to the JSON property osVersion
1135 1136 1137 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1135 def os_version @os_version end |
#other_accounts ⇒ Array<String>
Output only. Domain name for Google accounts on device. Type for other
accounts on device. On Android, will only be populated if |ownership_privilege|
is |PROFILE_OWNER| or |DEVICE_OWNER|. Does not include the account signed in
to the device policy app if that account's domain has only one account.
Examples: "com.example", "xyz.com".
Corresponds to the JSON property otherAccounts
1144 1145 1146 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1144 def other_accounts @other_accounts end |
#owner_type ⇒ String
Output only. Whether the device is owned by the company or an individual
Corresponds to the JSON property ownerType
1149 1150 1151 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1149 def owner_type @owner_type end |
#release_version ⇒ String
Output only. OS release version. Example: 6.0.
Corresponds to the JSON property releaseVersion
1154 1155 1156 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1154 def release_version @release_version end |
#security_patch_time ⇒ String
Output only. OS security patch update time on device.
Corresponds to the JSON property securityPatchTime
1159 1160 1161 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1159 def security_patch_time @security_patch_time end |
#serial_number ⇒ String
Serial Number of device. Example: HT82V1A01076.
Corresponds to the JSON property serialNumber
1164 1165 1166 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1164 def serial_number @serial_number end |
#unified_device_id ⇒ String
Output only. Unified device id of the device.
Corresponds to the JSON property unifiedDeviceId
1169 1170 1171 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1169 def unified_device_id @unified_device_id end |
#wifi_mac_addresses ⇒ Array<String>
WiFi MAC addresses of device.
Corresponds to the JSON property wifiMacAddresses
1174 1175 1176 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1174 def wifi_mac_addresses @wifi_mac_addresses end |
#windows_specific_device_attributes ⇒ Google::Apis::CloudidentityV1beta1::WindowsSpecificDeviceAttributes
Represents the Windows specific attributes of a Device.
Corresponds to the JSON property windowsSpecificDeviceAttributes
1179 1180 1181 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1179 def windows_specific_device_attributes @windows_specific_device_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1186 def update!(**args) @android_specific_attributes = args[:android_specific_attributes] if args.key?(:android_specific_attributes) @antivirus_info = args[:antivirus_info] if args.key?(:antivirus_info) @asset_tag = args[:asset_tag] if args.key?(:asset_tag) @baseband_version = args[:baseband_version] if args.key?(:baseband_version) @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version) @brand = args[:brand] if args.key?(:brand) @browser_profiles = args[:browser_profiles] if args.key?(:browser_profiles) @build_number = args[:build_number] if args.key?(:build_number) @client_types = args[:client_types] if args.key?(:client_types) @compromised_state = args[:compromised_state] if args.key?(:compromised_state) @create_time = args[:create_time] if args.key?(:create_time) @device_id = args[:device_id] if args.key?(:device_id) @device_type = args[:device_type] if args.key?(:device_type) @enabled_developer_options = args[:enabled_developer_options] if args.key?(:enabled_developer_options) @enabled_usb_debugging = args[:enabled_usb_debugging] if args.key?(:enabled_usb_debugging) @encryption_state = args[:encryption_state] if args.key?(:encryption_state) @endpoint_verification_specific_attributes = args[:endpoint_verification_specific_attributes] if args.key?(:endpoint_verification_specific_attributes) @hostname = args[:hostname] if args.key?(:hostname) @imei = args[:imei] if args.key?(:imei) @kernel_version = args[:kernel_version] if args.key?(:kernel_version) @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time) @management_state = args[:management_state] if args.key?(:management_state) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @meid = args[:meid] if args.key?(:meid) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @network_operator = args[:network_operator] if args.key?(:network_operator) @os_firewall_status = args[:os_firewall_status] if args.key?(:os_firewall_status) @os_version = args[:os_version] if args.key?(:os_version) @other_accounts = args[:other_accounts] if args.key?(:other_accounts) @owner_type = args[:owner_type] if args.key?(:owner_type) @release_version = args[:release_version] if args.key?(:release_version) @security_patch_time = args[:security_patch_time] if args.key?(:security_patch_time) @serial_number = args[:serial_number] if args.key?(:serial_number) @unified_device_id = args[:unified_device_id] if args.key?(:unified_device_id) @wifi_mac_addresses = args[:wifi_mac_addresses] if args.key?(:wifi_mac_addresses) @windows_specific_device_attributes = args[:windows_specific_device_attributes] if args.key?(:windows_specific_device_attributes) end |