Class: Google::Apis::CloudidentityV1beta1::Device

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

A Device within the Cloud Identity Devices API. Represents a Device known to Google Cloud, independent of the device ownership, type, and whether it is assigned or in use by a user. Important: Device API scopes require that you use domain-wide delegation to access the API. For more information, see Set up the Devices API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Device

Returns a new instance of Device.



1070
1071
1072
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_specific_attributesGoogle::Apis::CloudidentityV1beta1::AndroidAttributes

Resource representing the Android specific attributes of a Device. Corresponds to the JSON property androidSpecificAttributes



898
899
900
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 898

def android_specific_attributes
  @android_specific_attributes
end

#asset_tagString

Asset tag of the device. Corresponds to the JSON property assetTag

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 903

def asset_tag
  @asset_tag
end

#baseband_versionString

Output only. Baseband version of the device. Corresponds to the JSON property basebandVersion

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 908

def baseband_version
  @baseband_version
end

#bootloader_versionString

Output only. Device bootloader version. Example: 0.6.7. Corresponds to the JSON property bootloaderVersion

Returns:

  • (String)


913
914
915
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 913

def bootloader_version
  @bootloader_version
end

#brandString

Output only. Device brand. Example: Samsung. Corresponds to the JSON property brand

Returns:

  • (String)


918
919
920
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 918

def brand
  @brand
end

#build_numberString

Output only. Build number of the device. Corresponds to the JSON property buildNumber

Returns:

  • (String)


923
924
925
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 923

def build_number
  @build_number
end

#client_typesArray<String>

List of the clients the device is reporting to. Corresponds to the JSON property clientTypes

Returns:

  • (Array<String>)


928
929
930
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 928

def client_types
  @client_types
end

#compromised_stateString

Output only. Represents whether the Device is compromised. Corresponds to the JSON property compromisedState

Returns:

  • (String)


933
934
935
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 933

def compromised_state
  @compromised_state
end

#create_timeString

Output only. When the Company-Owned device was imported. This field is empty for BYOD devices. Corresponds to the JSON property createTime

Returns:

  • (String)


939
940
941
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 939

def create_time
  @create_time
end

#device_idString

Unique identifier for the device. Corresponds to the JSON property deviceId

Returns:

  • (String)


944
945
946
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 944

def device_id
  @device_id
end

#device_typeString

Output only. Type of device. Corresponds to the JSON property deviceType

Returns:

  • (String)


949
950
951
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 949

def device_type
  @device_type
end

#enabled_developer_optionsBoolean Also known as: enabled_developer_options?

Output only. Whether developer options is enabled on device. Corresponds to the JSON property enabledDeveloperOptions

Returns:

  • (Boolean)


954
955
956
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 954

def enabled_developer_options
  @enabled_developer_options
end

#enabled_usb_debuggingBoolean Also known as: enabled_usb_debugging?

Output only. Whether USB debugging is enabled on device. Corresponds to the JSON property enabledUsbDebugging

Returns:

  • (Boolean)


960
961
962
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 960

def enabled_usb_debugging
  @enabled_usb_debugging
end

#encryption_stateString

Output only. Device encryption state. Corresponds to the JSON property encryptionState

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 966

def encryption_state
  @encryption_state
end

#endpoint_verification_specific_attributesGoogle::Apis::CloudidentityV1beta1::EndpointVerificationSpecificAttributes

Resource representing the Endpoint Verification-specific attributes of a device. Corresponds to the JSON property endpointVerificationSpecificAttributes



972
973
974
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 972

def endpoint_verification_specific_attributes
  @endpoint_verification_specific_attributes
end

#hostnameString

Host name of the device. Corresponds to the JSON property hostname

Returns:

  • (String)


977
978
979
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 977

def hostname
  @hostname
end

#imeiString

Output only. IMEI number of device if GSM device; empty otherwise. Corresponds to the JSON property imei

Returns:

  • (String)


982
983
984
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 982

def imei
  @imei
end

#kernel_versionString

Output only. Kernel version of the device. Corresponds to the JSON property kernelVersion

Returns:

  • (String)


987
988
989
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 987

def kernel_version
  @kernel_version
end

#last_sync_timeString

Most recent time when device synced with this service. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 992

def last_sync_time
  @last_sync_time
end

#management_stateString

Output only. Management state of the device Corresponds to the JSON property managementState

Returns:

  • (String)


997
998
999
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 997

def management_state
  @management_state
end

#manufacturerString

Output only. Device manufacturer. Example: Motorola. Corresponds to the JSON property manufacturer

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1002

def manufacturer
  @manufacturer
end

#meidString

Output only. MEID number of device if CDMA device; empty otherwise. Corresponds to the JSON property meid

Returns:

  • (String)


1007
1008
1009
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1007

def meid
  @meid
end

#modelString

Output only. Model name of device. Example: Pixel 3. Corresponds to the JSON property model

Returns:

  • (String)


1012
1013
1014
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1012

def model
  @model
end

#nameString

Output only. Resource name of the Device in format: devices/device_id`, where device_id is the unique id assigned to the Device. Corresponds to the JSON propertyname`

Returns:

  • (String)


1019
1020
1021
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1019

def name
  @name
end

#network_operatorString

Output only. Mobile or network operator of device, if available. Corresponds to the JSON property networkOperator

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1024

def network_operator
  @network_operator
end

#os_versionString

Output only. OS version of the device. Example: Android 8.1.0. Corresponds to the JSON property osVersion

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1029

def os_version
  @os_version
end

#other_accountsArray<String>

Output only. Domain name for Google accounts on device. Type for other accounts on device. On Android, will only be populated if |ownership_privilege| is |PROFILE_OWNER| or |DEVICE_OWNER|. Does not include the account signed in to the device policy app if that account's domain has only one account. Examples: "com.example", "xyz.com". Corresponds to the JSON property otherAccounts

Returns:

  • (Array<String>)


1038
1039
1040
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1038

def other_accounts
  @other_accounts
end

#owner_typeString

Output only. Whether the device is owned by the company or an individual Corresponds to the JSON property ownerType

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1043

def owner_type
  @owner_type
end

#release_versionString

Output only. OS release version. Example: 6.0. Corresponds to the JSON property releaseVersion

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1048

def release_version
  @release_version
end

#security_patch_timeString

Output only. OS security patch update time on device. Corresponds to the JSON property securityPatchTime

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1053

def security_patch_time
  @security_patch_time
end

#serial_numberString

Serial Number of device. Example: HT82V1A01076. Corresponds to the JSON property serialNumber

Returns:

  • (String)


1058
1059
1060
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1058

def serial_number
  @serial_number
end

#unified_device_idString

Output only. Unified device id of the device. Corresponds to the JSON property unifiedDeviceId

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1063

def unified_device_id
  @unified_device_id
end

#wifi_mac_addressesArray<String>

WiFi MAC addresses of device. Corresponds to the JSON property wifiMacAddresses

Returns:

  • (Array<String>)


1068
1069
1070
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1068

def wifi_mac_addresses
  @wifi_mac_addresses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1075

def update!(**args)
  @android_specific_attributes = args[:android_specific_attributes] if args.key?(:android_specific_attributes)
  @asset_tag = args[:asset_tag] if args.key?(:asset_tag)
  @baseband_version = args[:baseband_version] if args.key?(:baseband_version)
  @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version)
  @brand = args[:brand] if args.key?(:brand)
  @build_number = args[:build_number] if args.key?(:build_number)
  @client_types = args[:client_types] if args.key?(:client_types)
  @compromised_state = args[:compromised_state] if args.key?(:compromised_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_type = args[:device_type] if args.key?(:device_type)
  @enabled_developer_options = args[:enabled_developer_options] if args.key?(:enabled_developer_options)
  @enabled_usb_debugging = args[:enabled_usb_debugging] if args.key?(:enabled_usb_debugging)
  @encryption_state = args[:encryption_state] if args.key?(:encryption_state)
  @endpoint_verification_specific_attributes = args[:endpoint_verification_specific_attributes] if args.key?(:endpoint_verification_specific_attributes)
  @hostname = args[:hostname] if args.key?(:hostname)
  @imei = args[:imei] if args.key?(:imei)
  @kernel_version = args[:kernel_version] if args.key?(:kernel_version)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @management_state = args[:management_state] if args.key?(:management_state)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @meid = args[:meid] if args.key?(:meid)
  @model = args[:model] if args.key?(:model)
  @name = args[:name] if args.key?(:name)
  @network_operator = args[:network_operator] if args.key?(:network_operator)
  @os_version = args[:os_version] if args.key?(:os_version)
  @other_accounts = args[:other_accounts] if args.key?(:other_accounts)
  @owner_type = args[:owner_type] if args.key?(:owner_type)
  @release_version = args[:release_version] if args.key?(:release_version)
  @security_patch_time = args[:security_patch_time] if args.key?(:security_patch_time)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @unified_device_id = args[:unified_device_id] if args.key?(:unified_device_id)
  @wifi_mac_addresses = args[:wifi_mac_addresses] if args.key?(:wifi_mac_addresses)
end