Class: Google::Apis::CloudidentityV1beta1::DynamicGroupMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::DynamicGroupMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Dynamic group metadata like queries and status.
Instance Attribute Summary collapse
-
#queries ⇒ Array<Google::Apis::CloudidentityV1beta1::DynamicGroupQuery>
Memberships will be the union of all queries.
-
#status ⇒ Google::Apis::CloudidentityV1beta1::DynamicGroupStatus
The current status of a dynamic group along with timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicGroupMetadata
constructor
A new instance of DynamicGroupMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicGroupMetadata
Returns a new instance of DynamicGroupMetadata.
1338 1339 1340 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#queries ⇒ Array<Google::Apis::CloudidentityV1beta1::DynamicGroupQuery>
Memberships will be the union of all queries. Only one entry with USER
resource is currently supported. Customers can create up to 500 dynamic groups.
Corresponds to the JSON property queries
1331 1332 1333 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1331 def queries @queries end |
#status ⇒ Google::Apis::CloudidentityV1beta1::DynamicGroupStatus
The current status of a dynamic group along with timestamp.
Corresponds to the JSON property status
1336 1337 1338 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1336 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1343 1344 1345 1346 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1343 def update!(**args) @queries = args[:queries] if args.key?(:queries) @status = args[:status] if args.key?(:status) end |