Class: Google::Apis::CloudidentityV1beta1::ExternalId
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::ExternalId
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
An external identifier for an entity in the Cloud Identity Groups API. Used to
link a Group in Cloud Identity Groups API with a corresponding entity in an
external identity system or directory.
Instance Attribute Summary collapse
-
#id ⇒ String
Required.
-
#namespace ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalId
constructor
A new instance of ExternalId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalId
Returns a new instance of ExternalId.
1547 1548 1549 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Required. The unique identifier assigned by the external identity provider.
The API does not enforce uniqueness of IDs across entities, but clients should
ensure IDs are unique within their namespace.
Corresponds to the JSON property id
1539 1540 1541 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1539 def id @id end |
#namespace ⇒ String
Required. The namespace in which the entity exists. Cannot be empty. Currently,
the only allowable namespace is "system/external".
Corresponds to the JSON property namespace
1545 1546 1547 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1545 def namespace @namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1552 1553 1554 1555 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1552 def update!(**args) @id = args[:id] if args.key?(:id) @namespace = args[:namespace] if args.key?(:namespace) end |