Class: Google::Apis::CloudidentityV1beta1::ExternalId

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

An external identifier for an entity in the Cloud Identity Groups API. Used to link a Group in Cloud Identity Groups API with a corresponding entity in an external identity system or directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalId

Returns a new instance of ExternalId.



1520
1521
1522
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. The unique identifier assigned by the external identity provider. The API does not enforce uniqueness of IDs across entities, but clients should ensure IDs are unique within their namespace. Corresponds to the JSON property id

Returns:

  • (String)


1512
1513
1514
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1512

def id
  @id
end

#namespaceString

Required. The namespace in which the entity exists. Cannot be empty. Currently, the only allowable namespace is "system/external". Corresponds to the JSON property namespace

Returns:

  • (String)


1518
1519
1520
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1518

def namespace
  @namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1525
1526
1527
1528
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1525

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @namespace = args[:namespace] if args.key?(:namespace)
end