Class: Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1AndroidAttributes
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1AndroidAttributes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Resource representing the Android specific attributes of a Device.
Instance Attribute Summary collapse
-
#cts_profile_match ⇒ Boolean
(also: #cts_profile_match?)
Whether the device passes Android CTS compliance.
-
#enabled_unknown_sources ⇒ Boolean
(also: #enabled_unknown_sources?)
Whether applications from unknown sources can be installed on device.
-
#has_potentially_harmful_apps ⇒ Boolean
(also: #has_potentially_harmful_apps?)
Whether any potentially harmful apps were detected on the device.
-
#owner_profile_account ⇒ Boolean
(also: #owner_profile_account?)
Whether this account is on an owner/primary profile.
-
#ownership_privilege ⇒ String
Ownership privileges on device.
-
#supports_work_profile ⇒ Boolean
(also: #supports_work_profile?)
Whether device supports Android work profiles.
-
#verified_boot ⇒ Boolean
(also: #verified_boot?)
Whether Android verified boot status is GREEN.
-
#verify_apps_enabled ⇒ Boolean
(also: #verify_apps_enabled?)
Whether Google Play Protect Verify Apps is enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1AndroidAttributes
constructor
A new instance of GoogleAppsCloudidentityDevicesV1AndroidAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1AndroidAttributes
Returns a new instance of GoogleAppsCloudidentityDevicesV1AndroidAttributes.
1468 1469 1470 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cts_profile_match ⇒ Boolean Also known as: cts_profile_match?
Whether the device passes Android CTS compliance.
Corresponds to the JSON property ctsProfileMatch
1420 1421 1422 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1420 def cts_profile_match @cts_profile_match end |
#enabled_unknown_sources ⇒ Boolean Also known as: enabled_unknown_sources?
Whether applications from unknown sources can be installed on device.
Corresponds to the JSON property enabledUnknownSources
1426 1427 1428 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1426 def enabled_unknown_sources @enabled_unknown_sources end |
#has_potentially_harmful_apps ⇒ Boolean Also known as: has_potentially_harmful_apps?
Whether any potentially harmful apps were detected on the device.
Corresponds to the JSON property hasPotentiallyHarmfulApps
1432 1433 1434 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1432 def has_potentially_harmful_apps @has_potentially_harmful_apps end |
#owner_profile_account ⇒ Boolean Also known as: owner_profile_account?
Whether this account is on an owner/primary profile. For phones, only true for
owner profiles. Android 4+ devices can have secondary or restricted user
profiles.
Corresponds to the JSON property ownerProfileAccount
1440 1441 1442 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1440 def owner_profile_account @owner_profile_account end |
#ownership_privilege ⇒ String
Ownership privileges on device.
Corresponds to the JSON property ownershipPrivilege
1446 1447 1448 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1446 def ownership_privilege @ownership_privilege end |
#supports_work_profile ⇒ Boolean Also known as: supports_work_profile?
Whether device supports Android work profiles. If false, this service will not
block access to corp data even if an administrator turns on the "Enforce Work
Profile" policy.
Corresponds to the JSON property supportsWorkProfile
1453 1454 1455 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1453 def supports_work_profile @supports_work_profile end |
#verified_boot ⇒ Boolean Also known as: verified_boot?
Whether Android verified boot status is GREEN.
Corresponds to the JSON property verifiedBoot
1459 1460 1461 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1459 def verified_boot @verified_boot end |
#verify_apps_enabled ⇒ Boolean Also known as: verify_apps_enabled?
Whether Google Play Protect Verify Apps is enabled.
Corresponds to the JSON property verifyAppsEnabled
1465 1466 1467 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1465 def verify_apps_enabled @verify_apps_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 1473 def update!(**args) @cts_profile_match = args[:cts_profile_match] if args.key?(:cts_profile_match) @enabled_unknown_sources = args[:enabled_unknown_sources] if args.key?(:enabled_unknown_sources) @has_potentially_harmful_apps = args[:has_potentially_harmful_apps] if args.key?(:has_potentially_harmful_apps) @owner_profile_account = args[:owner_profile_account] if args.key?(:owner_profile_account) @ownership_privilege = args[:ownership_privilege] if args.key?(:ownership_privilege) @supports_work_profile = args[:supports_work_profile] if args.key?(:supports_work_profile) @verified_boot = args[:verified_boot] if args.key?(:verified_boot) @verify_apps_enabled = args[:verify_apps_enabled] if args.key?(:verify_apps_enabled) end |