Class: Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1ClientState
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1ClientState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Represents the state associated with an API client calling the Devices API. Resource representing ClientState and supports updates from API users
Instance Attribute Summary collapse
-
#asset_tags ⇒ Array<String>
The caller can specify asset tags for this resource Corresponds to the JSON property
assetTags. -
#compliance_state ⇒ String
The compliance state of the resource as specified by the API client.
-
#create_time ⇒ String
Output only.
-
#custom_id ⇒ String
This field may be used to store a unique identifier for the API resource within which these CustomAttributes are a field.
-
#etag ⇒ String
The token that needs to be passed back for concurrency control in updates.
-
#health_score ⇒ String
The Health score of the resource.
-
#key_value_pairs ⇒ Hash<String,Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1CustomAttributeValue>
The map of key-value attributes stored by callers specific to a device.
-
#last_update_time ⇒ String
Output only.
-
#managed ⇒ String
The management state of the resource as specified by the API client.
-
#name ⇒ String
Output only.
-
#owner_type ⇒ String
Output only.
-
#score_reason ⇒ String
A descriptive cause of the health score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1ClientState
constructor
A new instance of GoogleAppsCloudidentityDevicesV1ClientState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1ClientState
Returns a new instance of GoogleAppsCloudidentityDevicesV1ClientState.
2080 2081 2082 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_tags ⇒ Array<String>
The caller can specify asset tags for this resource
Corresponds to the JSON property assetTags
2004 2005 2006 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2004 def @asset_tags end |
#compliance_state ⇒ String
The compliance state of the resource as specified by the API client.
Corresponds to the JSON property complianceState
2009 2010 2011 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2009 def compliance_state @compliance_state end |
#create_time ⇒ String
Output only. The time the client state data was created.
Corresponds to the JSON property createTime
2014 2015 2016 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2014 def create_time @create_time end |
#custom_id ⇒ String
This field may be used to store a unique identifier for the API resource
within which these CustomAttributes are a field.
Corresponds to the JSON property customId
2020 2021 2022 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2020 def custom_id @custom_id end |
#etag ⇒ String
The token that needs to be passed back for concurrency control in updates.
Token needs to be passed back in UpdateRequest
Corresponds to the JSON property etag
2026 2027 2028 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2026 def etag @etag end |
#health_score ⇒ String
The Health score of the resource. The Health score is the callers
specification of the condition of the device from a usability point of view.
For example, a third-party device management provider may specify a health
score based on its compliance with organizational policies.
Corresponds to the JSON property healthScore
2034 2035 2036 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2034 def health_score @health_score end |
#key_value_pairs ⇒ Hash<String,Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1CustomAttributeValue>
The map of key-value attributes stored by callers specific to a device. The
total serialized length of this map may not exceed 10KB. No limit is placed on
the number of attributes in a map.
Corresponds to the JSON property keyValuePairs
2041 2042 2043 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2041 def key_value_pairs @key_value_pairs end |
#last_update_time ⇒ String
Output only. The time the client state data was last updated.
Corresponds to the JSON property lastUpdateTime
2046 2047 2048 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2046 def last_update_time @last_update_time end |
#managed ⇒ String
The management state of the resource as specified by the API client.
Corresponds to the JSON property managed
2051 2052 2053 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2051 def managed @managed end |
#name ⇒ String
Output only. Resource name of the ClientState in format: devices/device/deviceUsers/
device_user/clientState/partner, where partner corresponds to the partner
storing the data. For partners belonging to the "BeyondCorp Alliance", this is
the partner ID specified to you by Google. For all other callers, this is a
string of the form:customer-suffix, where customer is your customer ID.
The suffix is any string the caller specifies. This string will be displayed
verbatim in the administration console. This suffix is used in setting up
Custom Access Levels in Context-Aware Access. Your organization's customer ID
can be obtained from the URL: GET https://www.googleapis.com/admin/directory/
v1/customers/my_customer The id field in the response contains the customer
ID starting with the letter 'C'. The customer ID to be used in this API is the
string after the letter 'C' (not including 'C')
Corresponds to the JSON property name
2068 2069 2070 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2068 def name @name end |
#owner_type ⇒ String
Output only. The owner of the ClientState
Corresponds to the JSON property ownerType
2073 2074 2075 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2073 def owner_type @owner_type end |
#score_reason ⇒ String
A descriptive cause of the health score.
Corresponds to the JSON property scoreReason
2078 2079 2080 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2078 def score_reason @score_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2085 def update!(**args) @asset_tags = args[:asset_tags] if args.key?(:asset_tags) @compliance_state = args[:compliance_state] if args.key?(:compliance_state) @create_time = args[:create_time] if args.key?(:create_time) @custom_id = args[:custom_id] if args.key?(:custom_id) @etag = args[:etag] if args.key?(:etag) @health_score = args[:health_score] if args.key?(:health_score) @key_value_pairs = args[:key_value_pairs] if args.key?(:key_value_pairs) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @managed = args[:managed] if args.key?(:managed) @name = args[:name] if args.key?(:name) @owner_type = args[:owner_type] if args.key?(:owner_type) @score_reason = args[:score_reason] if args.key?(:score_reason) end |