Class: Google::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1Device

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

A Device within the Cloud Identity Devices API. Represents a Device known to Google Cloud, independent of the device ownership, type, and whether it is assigned or in use by a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1Device

Returns a new instance of GoogleAppsCloudidentityDevicesV1Device.



2351
2352
2353
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_specific_attributesGoogle::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1AndroidAttributes

Resource representing the Android specific attributes of a Device. Corresponds to the JSON property androidSpecificAttributes



2181
2182
2183
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2181

def android_specific_attributes
  @android_specific_attributes
end

#asset_tagString

Asset tag of the device. Corresponds to the JSON property assetTag

Returns:

  • (String)


2186
2187
2188
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2186

def asset_tag
  @asset_tag
end

#baseband_versionString

Output only. Baseband version of the device. Corresponds to the JSON property basebandVersion

Returns:

  • (String)


2191
2192
2193
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2191

def baseband_version
  @baseband_version
end

#bootloader_versionString

Output only. Device bootloader version. Example: 0.6.7. Corresponds to the JSON property bootloaderVersion

Returns:

  • (String)


2196
2197
2198
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2196

def bootloader_version
  @bootloader_version
end

#brandString

Output only. Device brand. Example: Samsung. Corresponds to the JSON property brand

Returns:

  • (String)


2201
2202
2203
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2201

def brand
  @brand
end

#build_numberString

Output only. Build number of the device. Corresponds to the JSON property buildNumber

Returns:

  • (String)


2206
2207
2208
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2206

def build_number
  @build_number
end

#compromised_stateString

Output only. Represents whether the Device is compromised. Corresponds to the JSON property compromisedState

Returns:

  • (String)


2211
2212
2213
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2211

def compromised_state
  @compromised_state
end

#create_timeString

Output only. When the Company-Owned device was imported. This field is empty for BYOD devices. Corresponds to the JSON property createTime

Returns:

  • (String)


2217
2218
2219
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2217

def create_time
  @create_time
end

#device_idString

Unique identifier for the device. Corresponds to the JSON property deviceId

Returns:

  • (String)


2222
2223
2224
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2222

def device_id
  @device_id
end

#device_typeString

Output only. Type of device. Corresponds to the JSON property deviceType

Returns:

  • (String)


2227
2228
2229
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2227

def device_type
  @device_type
end

#enabled_developer_optionsBoolean Also known as: enabled_developer_options?

Output only. Whether developer options is enabled on device. Corresponds to the JSON property enabledDeveloperOptions

Returns:

  • (Boolean)


2232
2233
2234
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2232

def enabled_developer_options
  @enabled_developer_options
end

#enabled_usb_debuggingBoolean Also known as: enabled_usb_debugging?

Output only. Whether USB debugging is enabled on device. Corresponds to the JSON property enabledUsbDebugging

Returns:

  • (Boolean)


2238
2239
2240
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2238

def enabled_usb_debugging
  @enabled_usb_debugging
end

#encryption_stateString

Output only. Device encryption state. Corresponds to the JSON property encryptionState

Returns:

  • (String)


2244
2245
2246
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2244

def encryption_state
  @encryption_state
end

#endpoint_verification_specific_attributesGoogle::Apis::CloudidentityV1beta1::GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes

Resource representing the Endpoint Verification-specific attributes of a device. Corresponds to the JSON property endpointVerificationSpecificAttributes



2250
2251
2252
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2250

def endpoint_verification_specific_attributes
  @endpoint_verification_specific_attributes
end

#hostnameString

Host name of the device. Corresponds to the JSON property hostname

Returns:

  • (String)


2255
2256
2257
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2255

def hostname
  @hostname
end

#imeiString

Output only. IMEI number of device if GSM device; empty otherwise. Corresponds to the JSON property imei

Returns:

  • (String)


2260
2261
2262
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2260

def imei
  @imei
end

#kernel_versionString

Output only. Kernel version of the device. Corresponds to the JSON property kernelVersion

Returns:

  • (String)


2265
2266
2267
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2265

def kernel_version
  @kernel_version
end

#last_sync_timeString

Most recent time when device synced with this service. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2270
2271
2272
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2270

def last_sync_time
  @last_sync_time
end

#management_stateString

Output only. Management state of the device Corresponds to the JSON property managementState

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2275

def management_state
  @management_state
end

#manufacturerString

Output only. Device manufacturer. Example: Motorola. Corresponds to the JSON property manufacturer

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2280

def manufacturer
  @manufacturer
end

#meidString

Output only. MEID number of device if CDMA device; empty otherwise. Corresponds to the JSON property meid

Returns:

  • (String)


2285
2286
2287
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2285

def meid
  @meid
end

#modelString

Output only. Model name of device. Example: Pixel 3. Corresponds to the JSON property model

Returns:

  • (String)


2290
2291
2292
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2290

def model
  @model
end

#nameString

Output only. Resource name of the Device in format: devices/device`, where device is the unique id assigned to the Device. Important: Device API scopes require that you use domain-wide delegation to access the API. For more information, see [Set up the Devices API](https://cloud.google.com/identity/docs/how-to/ setup-devices). Corresponds to the JSON propertyname`

Returns:

  • (String)


2300
2301
2302
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2300

def name
  @name
end

#network_operatorString

Output only. Mobile or network operator of device, if available. Corresponds to the JSON property networkOperator

Returns:

  • (String)


2305
2306
2307
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2305

def network_operator
  @network_operator
end

#os_versionString

Output only. OS version of the device. Example: Android 8.1.0. Corresponds to the JSON property osVersion

Returns:

  • (String)


2310
2311
2312
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2310

def os_version
  @os_version
end

#other_accountsArray<String>

Output only. Domain name for Google accounts on device. Type for other accounts on device. On Android, will only be populated if |ownership_privilege| is |PROFILE_OWNER| or |DEVICE_OWNER|. Does not include the account signed in to the device policy app if that account's domain has only one account. Examples: "com.example", "xyz.com". Corresponds to the JSON property otherAccounts

Returns:

  • (Array<String>)


2319
2320
2321
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2319

def other_accounts
  @other_accounts
end

#owner_typeString

Output only. Whether the device is owned by the company or an individual Corresponds to the JSON property ownerType

Returns:

  • (String)


2324
2325
2326
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2324

def owner_type
  @owner_type
end

#release_versionString

Output only. OS release version. Example: 6.0. Corresponds to the JSON property releaseVersion

Returns:

  • (String)


2329
2330
2331
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2329

def release_version
  @release_version
end

#security_patch_timeString

Output only. OS security patch update time on device. Corresponds to the JSON property securityPatchTime

Returns:

  • (String)


2334
2335
2336
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2334

def security_patch_time
  @security_patch_time
end

#serial_numberString

Serial Number of device. Example: HT82V1A01076. Corresponds to the JSON property serialNumber

Returns:

  • (String)


2339
2340
2341
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2339

def serial_number
  @serial_number
end

#unified_device_idString

Output only. Unified device id of the device. Corresponds to the JSON property unifiedDeviceId

Returns:

  • (String)


2344
2345
2346
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2344

def unified_device_id
  @unified_device_id
end

#wifi_mac_addressesArray<String>

WiFi MAC addresses of device. Corresponds to the JSON property wifiMacAddresses

Returns:

  • (Array<String>)


2349
2350
2351
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2349

def wifi_mac_addresses
  @wifi_mac_addresses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2356

def update!(**args)
  @android_specific_attributes = args[:android_specific_attributes] if args.key?(:android_specific_attributes)
  @asset_tag = args[:asset_tag] if args.key?(:asset_tag)
  @baseband_version = args[:baseband_version] if args.key?(:baseband_version)
  @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version)
  @brand = args[:brand] if args.key?(:brand)
  @build_number = args[:build_number] if args.key?(:build_number)
  @compromised_state = args[:compromised_state] if args.key?(:compromised_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_type = args[:device_type] if args.key?(:device_type)
  @enabled_developer_options = args[:enabled_developer_options] if args.key?(:enabled_developer_options)
  @enabled_usb_debugging = args[:enabled_usb_debugging] if args.key?(:enabled_usb_debugging)
  @encryption_state = args[:encryption_state] if args.key?(:encryption_state)
  @endpoint_verification_specific_attributes = args[:endpoint_verification_specific_attributes] if args.key?(:endpoint_verification_specific_attributes)
  @hostname = args[:hostname] if args.key?(:hostname)
  @imei = args[:imei] if args.key?(:imei)
  @kernel_version = args[:kernel_version] if args.key?(:kernel_version)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @management_state = args[:management_state] if args.key?(:management_state)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @meid = args[:meid] if args.key?(:meid)
  @model = args[:model] if args.key?(:model)
  @name = args[:name] if args.key?(:name)
  @network_operator = args[:network_operator] if args.key?(:network_operator)
  @os_version = args[:os_version] if args.key?(:os_version)
  @other_accounts = args[:other_accounts] if args.key?(:other_accounts)
  @owner_type = args[:owner_type] if args.key?(:owner_type)
  @release_version = args[:release_version] if args.key?(:release_version)
  @security_patch_time = args[:security_patch_time] if args.key?(:security_patch_time)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @unified_device_id = args[:unified_device_id] if args.key?(:unified_device_id)
  @wifi_mac_addresses = args[:wifi_mac_addresses] if args.key?(:wifi_mac_addresses)
end