Class: Google::Apis::CloudidentityV1beta1::Group
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::Group
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
A group within the Cloud Identity Groups API. A Group is a collection of
entities, where each entity is either a user, another group, or a service
account.
Instance Attribute Summary collapse
-
#additional_group_keys ⇒ Array<Google::Apis::CloudidentityV1beta1::EntityKey>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
An extended description to help users determine the purpose of a
Group. -
#display_name ⇒ String
The display name of the
Group. -
#dynamic_group_metadata ⇒ Google::Apis::CloudidentityV1beta1::DynamicGroupMetadata
Dynamic group metadata like queries and status.
-
#group_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API.
-
#labels ⇒ Hash<String,String>
Required.
-
#name ⇒ String
Output only.
-
#parent ⇒ String
Required.
-
#posix_groups ⇒ Array<Google::Apis::CloudidentityV1beta1::PosixGroup>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Group
constructor
A new instance of Group.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Group
Returns a new instance of Group.
2709 2710 2711 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_group_keys ⇒ Array<Google::Apis::CloudidentityV1beta1::EntityKey>
Output only. Additional group keys associated with the Group.
Corresponds to the JSON property additionalGroupKeys
2635 2636 2637 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2635 def additional_group_keys @additional_group_keys end |
#create_time ⇒ String
Output only. The time when the Group was created.
Corresponds to the JSON property createTime
2640 2641 2642 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2640 def create_time @create_time end |
#description ⇒ String
An extended description to help users determine the purpose of a Group. Must
not be longer than 4,096 characters.
Corresponds to the JSON property description
2646 2647 2648 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2646 def description @description end |
#display_name ⇒ String
The display name of the Group.
Corresponds to the JSON property displayName
2651 2652 2653 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2651 def display_name @display_name end |
#dynamic_group_metadata ⇒ Google::Apis::CloudidentityV1beta1::DynamicGroupMetadata
Dynamic group metadata like queries and status.
Corresponds to the JSON property dynamicGroupMetadata
2656 2657 2658 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2656 def @dynamic_group_metadata end |
#group_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity
can represent either a group with an optional namespace or a user without a
namespace. The combination of id and namespace must be unique; however,
the same id can be used with different namespaces.
Corresponds to the JSON property groupKey
2664 2665 2666 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2664 def group_key @group_key end |
#labels ⇒ Hash<String,String>
Required. One or more label entries that apply to the Group. Labels contain a
key with an empty value. Google Groups are the default type of group and have
a label with a key of cloudidentity.googleapis.com/groups.discussion_forum
and an empty value. Existing Google Groups can have an additional label with a
key of cloudidentity.googleapis.com/groups.security and an empty value added
to them. This is an immutable change and the security label cannot be
removed once added. Dynamic groups have a label with a key of cloudidentity.
googleapis.com/groups.dynamic. Identity-mapped groups for Cloud Search have a
label with a key of system/groups/external and an empty value. Google Groups
can be locked. To lock a group,
add a label with a key of cloudidentity.googleapis.com/groups.locked and an
empty value. Doing so locks the group. To unlock the group, remove this label.
Corresponds to the JSON property labels
2680 2681 2682 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2680 def labels @labels end |
#name ⇒ String
Output only. The resource name of the Group. Shall be of the form groups/group_id`.
Corresponds to the JSON propertyname`
2686 2687 2688 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2686 def name @name end |
#parent ⇒ String
Required. Immutable. The resource name of the entity under which this Group
resides in the Cloud Identity resource hierarchy. Must be of the form
identitysources/identity_sourcefor external [identity-mapped groups](https:
//support.google.com/a/answer/9039510) or `customers/`customer_id for Google
Groups. The customer_id must begin with "C" (for example, 'C046psxkn').
Find your customer ID.
Corresponds to the JSON property parent
2697 2698 2699 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2697 def parent @parent end |
#posix_groups ⇒ Array<Google::Apis::CloudidentityV1beta1::PosixGroup>
Optional. The POSIX groups associated with the Group.
Corresponds to the JSON property posixGroups
2702 2703 2704 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2702 def posix_groups @posix_groups end |
#update_time ⇒ String
Output only. The time when the Group was last updated.
Corresponds to the JSON property updateTime
2707 2708 2709 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2707 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 2714 def update!(**args) @additional_group_keys = args[:additional_group_keys] if args.key?(:additional_group_keys) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @dynamic_group_metadata = args[:dynamic_group_metadata] if args.key?(:dynamic_group_metadata) @group_key = args[:group_key] if args.key?(:group_key) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @posix_groups = args[:posix_groups] if args.key?(:posix_groups) @update_time = args[:update_time] if args.key?(:update_time) end |