Class: Google::Apis::CloudidentityV1beta1::Membership
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::Membership
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
A membership within the Cloud Identity Groups API. A Membership defines a
relationship between a Group and an entity belonging to that Group,
referred to as a "member".
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delivery_setting ⇒ String
Output only.
-
#member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API.
-
#name ⇒ String
Output only.
-
#preferred_member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API.
-
#roles ⇒ Array<Google::Apis::CloudidentityV1beta1::MembershipRole>
The
MembershipRoles that apply to theMembership. -
#type ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Membership
constructor
A new instance of Membership.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Membership
Returns a new instance of Membership.
3401 3402 3403 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the Membership was created.
Corresponds to the JSON property createTime
3354 3355 3356 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3354 def create_time @create_time end |
#delivery_setting ⇒ String
Output only. Delivery setting associated with the membership.
Corresponds to the JSON property deliverySetting
3359 3360 3361 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3359 def delivery_setting @delivery_setting end |
#member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity
can represent either a group with an optional namespace or a user without a
namespace. The combination of id and namespace must be unique; however,
the same id can be used with different namespaces.
Corresponds to the JSON property memberKey
3367 3368 3369 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3367 def member_key @member_key end |
#name ⇒ String
Output only. The resource name of the Membership. Shall be of the form groups/group_id/
memberships/membership_id`.
Corresponds to the JSON propertyname`
3374 3375 3376 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3374 def name @name end |
#preferred_member_key ⇒ Google::Apis::CloudidentityV1beta1::EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity
can represent either a group with an optional namespace or a user without a
namespace. The combination of id and namespace must be unique; however,
the same id can be used with different namespaces.
Corresponds to the JSON property preferredMemberKey
3382 3383 3384 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3382 def preferred_member_key @preferred_member_key end |
#roles ⇒ Array<Google::Apis::CloudidentityV1beta1::MembershipRole>
The MembershipRoles that apply to the Membership. If unspecified, defaults
to a single MembershipRole with name MEMBER. Must not contain duplicate
MembershipRoles with the same name.
Corresponds to the JSON property roles
3389 3390 3391 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3389 def roles @roles end |
#type ⇒ String
Output only. The type of the membership.
Corresponds to the JSON property type
3394 3395 3396 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3394 def type @type end |
#update_time ⇒ String
Output only. The time when the Membership was last updated.
Corresponds to the JSON property updateTime
3399 3400 3401 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3399 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 3406 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delivery_setting = args[:delivery_setting] if args.key?(:delivery_setting) @member_key = args[:member_key] if args.key?(:member_key) @name = args[:name] if args.key?(:name) @preferred_member_key = args[:preferred_member_key] if args.key?(:preferred_member_key) @roles = args[:roles] if args.key?(:roles) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |