Class: Google::Apis::CloudidentityV1beta1::PolicyQuery

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

PolicyQuery

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyQuery

Returns a new instance of PolicyQuery.



4126
4127
4128
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

Immutable. The group that the query applies to. This field is only set if there is a single value for group that satisfies all clauses of the query. If no group applies, this will be the empty string. Corresponds to the JSON property group

Returns:

  • (String)


4093
4094
4095
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4093

def group
  @group
end

#org_unitString

Required. Immutable. Non-empty default. The OrgUnit the query applies to. This field is only set if there is a single value for org_unit that satisfies all clauses of the query. Corresponds to the JSON property orgUnit

Returns:

  • (String)


4100
4101
4102
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4100

def org_unit
  @org_unit
end

#queryString

Immutable. The CEL query that defines which entities the Policy applies to (ex. a User entity). For details about CEL see https://opensource.google.com/ projects/cel. The OrgUnits the Policy applies to are represented by a clause like so: entity.org_units.exists(org_unit, org_unit.org_unit_id == orgUnitId(' orgUnitId')) The Group the Policy applies to are represented by a clause like so: entity.groups.exists(group, group.group_id == groupId('groupId')) The Licenses the Policy applies to are represented by a clause like so: entity. licenses.exists(license, license in ['/product/productId/sku/skuId']) ** Note:** The licenses clause is not supported in mutate endpoints. The above clauses can be present in any combination, and used in conjunction with the &&, || and ! operators. The org_unit and group fields below are helper fields that contain the corresponding value(s) as the query to make the query easier to use. Corresponds to the JSON property query

Returns:

  • (String)


4117
4118
4119
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4117

def query
  @query
end

#sort_orderFloat

Output only. The decimal sort order of this PolicyQuery. The value is relative to all other policies with the same setting type for the customer. (There are no duplicates within this set). Corresponds to the JSON property sortOrder

Returns:

  • (Float)


4124
4125
4126
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4124

def sort_order
  @sort_order
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4131
4132
4133
4134
4135
4136
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4131

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @org_unit = args[:org_unit] if args.key?(:org_unit)
  @query = args[:query] if args.key?(:query)
  @sort_order = args[:sort_order] if args.key?(:sort_order)
end