Class: Google::Apis::CloudidentityV1beta1::SamlIdpConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::SamlIdpConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
SAML IDP (identity provider) configuration.
Instance Attribute Summary collapse
-
#change_password_uri ⇒ String
The Change Password URL of the identity provider.
-
#entity_id ⇒ String
Required.
-
#logout_redirect_uri ⇒ String
The Logout Redirect URL (sign-out page URL) of the identity provider.
-
#single_sign_on_service_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SamlIdpConfig
constructor
A new instance of SamlIdpConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SamlIdpConfig
Returns a new instance of SamlIdpConfig.
4263 4264 4265 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#change_password_uri ⇒ String
The Change Password URL of the identity provider. Users will be sent to
this URL when changing their passwords at myaccount.google.com. This takes
precedence over the change password URL configured at customer-level. Must use
HTTPS.
Corresponds to the JSON property changePasswordUri
4241 4242 4243 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4241 def change_password_uri @change_password_uri end |
#entity_id ⇒ String
Required. The SAML Entity ID of the identity provider.
Corresponds to the JSON property entityId
4246 4247 4248 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4246 def entity_id @entity_id end |
#logout_redirect_uri ⇒ String
The Logout Redirect URL (sign-out page URL) of the identity provider. When
a user clicks the sign-out link on a Google page, they will be redirected to
this URL. This is a pure redirect with no attached SAML LogoutRequest i.e.
SAML single logout is not supported. Must use HTTPS.
Corresponds to the JSON property logoutRedirectUri
4254 4255 4256 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4254 def logout_redirect_uri @logout_redirect_uri end |
#single_sign_on_service_uri ⇒ String
Required. The SingleSignOnService endpoint location (sign-in page URL) of
the identity provider. This is the URL where the AuthnRequest will be sent.
Must use HTTPS. Assumed to accept the HTTP-Redirect binding.
Corresponds to the JSON property singleSignOnServiceUri
4261 4262 4263 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4261 def single_sign_on_service_uri @single_sign_on_service_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4268 4269 4270 4271 4272 4273 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4268 def update!(**args) @change_password_uri = args[:change_password_uri] if args.key?(:change_password_uri) @entity_id = args[:entity_id] if args.key?(:entity_id) @logout_redirect_uri = args[:logout_redirect_uri] if args.key?(:logout_redirect_uri) @single_sign_on_service_uri = args[:single_sign_on_service_uri] if args.key?(:single_sign_on_service_uri) end |