Class: Google::Apis::CloudidentityV1beta1::SamlIdpConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

SAML IDP (identity provider) configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SamlIdpConfig

Returns a new instance of SamlIdpConfig.



4224
4225
4226
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_password_uriString

The Change Password URL of the identity provider. Users will be sent to this URL when changing their passwords at myaccount.google.com. This takes precedence over the change password URL configured at customer-level. Must use HTTPS. Corresponds to the JSON property changePasswordUri

Returns:

  • (String)


4202
4203
4204
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4202

def change_password_uri
  @change_password_uri
end

#entity_idString

Required. The SAML Entity ID of the identity provider. Corresponds to the JSON property entityId

Returns:

  • (String)


4207
4208
4209
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4207

def entity_id
  @entity_id
end

#logout_redirect_uriString

The Logout Redirect URL (sign-out page URL) of the identity provider. When a user clicks the sign-out link on a Google page, they will be redirected to this URL. This is a pure redirect with no attached SAML LogoutRequest i.e. SAML single logout is not supported. Must use HTTPS. Corresponds to the JSON property logoutRedirectUri

Returns:

  • (String)


4215
4216
4217
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4215

def logout_redirect_uri
  @logout_redirect_uri
end

#single_sign_on_service_uriString

Required. The SingleSignOnService endpoint location (sign-in page URL) of the identity provider. This is the URL where the AuthnRequest will be sent. Must use HTTPS. Assumed to accept the HTTP-Redirect binding. Corresponds to the JSON property singleSignOnServiceUri

Returns:

  • (String)


4222
4223
4224
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4222

def single_sign_on_service_uri
  @single_sign_on_service_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4229
4230
4231
4232
4233
4234
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4229

def update!(**args)
  @change_password_uri = args[:change_password_uri] if args.key?(:change_password_uri)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @logout_redirect_uri = args[:logout_redirect_uri] if args.key?(:logout_redirect_uri)
  @single_sign_on_service_uri = args[:single_sign_on_service_uri] if args.key?(:single_sign_on_service_uri)
end