Class: Google::Apis::CloudidentityV1beta1::SamlIdpConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

SAML IDP (identity provider) configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SamlIdpConfig

Returns a new instance of SamlIdpConfig.



4075
4076
4077
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_password_uriString

The Change Password URL of the identity provider. Users will be sent to this URL when changing their passwords at myaccount.google.com. This takes precedence over the change password URL configured at customer-level. Must use HTTPS. Corresponds to the JSON property changePasswordUri

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4053

def change_password_uri
  @change_password_uri
end

#entity_idString

Required. The SAML Entity ID of the identity provider. Corresponds to the JSON property entityId

Returns:

  • (String)


4058
4059
4060
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4058

def entity_id
  @entity_id
end

#logout_redirect_uriString

The Logout Redirect URL (sign-out page URL) of the identity provider. When a user clicks the sign-out link on a Google page, they will be redirected to this URL. This is a pure redirect with no attached SAML LogoutRequest i.e. SAML single logout is not supported. Must use HTTPS. Corresponds to the JSON property logoutRedirectUri

Returns:

  • (String)


4066
4067
4068
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4066

def logout_redirect_uri
  @logout_redirect_uri
end

#single_sign_on_service_uriString

Required. The SingleSignOnService endpoint location (sign-in page URL) of the identity provider. This is the URL where the AuthnRequest will be sent. Must use HTTPS. Assumed to accept the HTTP-Redirect binding. Corresponds to the JSON property singleSignOnServiceUri

Returns:

  • (String)


4073
4074
4075
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4073

def single_sign_on_service_uri
  @single_sign_on_service_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4080
4081
4082
4083
4084
4085
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4080

def update!(**args)
  @change_password_uri = args[:change_password_uri] if args.key?(:change_password_uri)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @logout_redirect_uri = args[:logout_redirect_uri] if args.key?(:logout_redirect_uri)
  @single_sign_on_service_uri = args[:single_sign_on_service_uri] if args.key?(:single_sign_on_service_uri)
end