Class: Google::Apis::CloudidentityV1beta1::UserInvitation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

The UserInvitation resource represents an email that can be sent to an unmanaged user account inviting them to join the customer's Google Workspace or Cloud Identity account. An unmanaged account shares an email address domain with the Google Workspace or Cloud Identity account but is not managed by it yet. If the user accepts the UserInvitation, the user account will become managed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserInvitation

Returns a new instance of UserInvitation.



4685
4686
4687
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mails_sent_countFixnum

Number of invitation emails sent to the user. Corresponds to the JSON property mailsSentCount

Returns:

  • (Fixnum)


4667
4668
4669
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4667

def mails_sent_count
  @mails_sent_count
end

#nameString

Shall be of the form customers/customer/userinvitations/user_email_address . Corresponds to the JSON property name

Returns:

  • (String)


4673
4674
4675
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4673

def name
  @name
end

#stateString

State of the UserInvitation. Corresponds to the JSON property state

Returns:

  • (String)


4678
4679
4680
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4678

def state
  @state
end

#update_timeString

Time when the UserInvitation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4683
4684
4685
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4683

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4690
4691
4692
4693
4694
4695
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4690

def update!(**args)
  @mails_sent_count = args[:mails_sent_count] if args.key?(:mails_sent_count)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end