Class: Google::Apis::CloudidentityV1beta1::UserInvitation
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::UserInvitation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
The UserInvitation resource represents an email that can be sent to an
unmanaged user account inviting them to join the customer's Google Workspace
or Cloud Identity account. An unmanaged account shares an email address domain
with the Google Workspace or Cloud Identity account but is not managed by it
yet. If the user accepts the UserInvitation, the user account will become
managed.
Instance Attribute Summary collapse
-
#mails_sent_count ⇒ Fixnum
Number of invitation emails sent to the user.
-
#name ⇒ String
Shall be of the form
customers/customer/userinvitations/user_email_address. -
#state ⇒ String
State of the
UserInvitation. -
#update_time ⇒ String
Time when the
UserInvitationwas last updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserInvitation
constructor
A new instance of UserInvitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserInvitation
Returns a new instance of UserInvitation.
4685 4686 4687 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mails_sent_count ⇒ Fixnum
Number of invitation emails sent to the user.
Corresponds to the JSON property mailsSentCount
4667 4668 4669 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4667 def mails_sent_count @mails_sent_count end |
#name ⇒ String
Shall be of the form customers/customer/userinvitations/user_email_address
.
Corresponds to the JSON property name
4673 4674 4675 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4673 def name @name end |
#state ⇒ String
State of the UserInvitation.
Corresponds to the JSON property state
4678 4679 4680 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4678 def state @state end |
#update_time ⇒ String
Time when the UserInvitation was last updated.
Corresponds to the JSON property updateTime
4683 4684 4685 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4683 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4690 4691 4692 4693 4694 4695 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4690 def update!(**args) @mails_sent_count = args[:mails_sent_count] if args.key?(:mails_sent_count) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |