Class: Google::Apis::CloudidentityV1beta1::UserInvitation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

The UserInvitation resource represents an email that can be sent to an unmanaged user account inviting them to join the customer's Google Workspace or Cloud Identity account. An unmanaged account shares an email address domain with the Google Workspace or Cloud Identity account but is not managed by it yet. If the user accepts the UserInvitation, the user account will become managed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserInvitation

Returns a new instance of UserInvitation.



4646
4647
4648
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mails_sent_countFixnum

Number of invitation emails sent to the user. Corresponds to the JSON property mailsSentCount

Returns:

  • (Fixnum)


4628
4629
4630
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4628

def mails_sent_count
  @mails_sent_count
end

#nameString

Shall be of the form customers/customer/userinvitations/user_email_address . Corresponds to the JSON property name

Returns:

  • (String)


4634
4635
4636
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4634

def name
  @name
end

#stateString

State of the UserInvitation. Corresponds to the JSON property state

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4639

def state
  @state
end

#update_timeString

Time when the UserInvitation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4644
4645
4646
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4644

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4651
4652
4653
4654
4655
4656
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4651

def update!(**args)
  @mails_sent_count = args[:mails_sent_count] if args.key?(:mails_sent_count)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end