Class: Google::Apis::CloudidentityV1beta1::UserInvitation
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::UserInvitation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
The UserInvitation resource represents an email that can be sent to an
unmanaged user account inviting them to join the customer's Google Workspace
or Cloud Identity account. An unmanaged account shares an email address domain
with the Google Workspace or Cloud Identity account but is not managed by it
yet. If the user accepts the UserInvitation, the user account will become
managed.
Instance Attribute Summary collapse
-
#mails_sent_count ⇒ Fixnum
Number of invitation emails sent to the user.
-
#name ⇒ String
Shall be of the form
customers/customer/userinvitations/user_email_address. -
#state ⇒ String
State of the
UserInvitation. -
#update_time ⇒ String
Time when the
UserInvitationwas last updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserInvitation
constructor
A new instance of UserInvitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserInvitation
Returns a new instance of UserInvitation.
4645 4646 4647 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mails_sent_count ⇒ Fixnum
Number of invitation emails sent to the user.
Corresponds to the JSON property mailsSentCount
4627 4628 4629 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4627 def mails_sent_count @mails_sent_count end |
#name ⇒ String
Shall be of the form customers/customer/userinvitations/user_email_address
.
Corresponds to the JSON property name
4633 4634 4635 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4633 def name @name end |
#state ⇒ String
State of the UserInvitation.
Corresponds to the JSON property state
4638 4639 4640 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4638 def state @state end |
#update_time ⇒ String
Time when the UserInvitation was last updated.
Corresponds to the JSON property updateTime
4643 4644 4645 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4643 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4650 4651 4652 4653 4654 4655 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4650 def update!(**args) @mails_sent_count = args[:mails_sent_count] if args.key?(:mails_sent_count) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |