Class: Google::Apis::CloudidentityV1beta1::WindowsSpecificDeviceAttributes
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1beta1::WindowsSpecificDeviceAttributes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb
Overview
Represents the Windows specific attributes of a Device.
Instance Attribute Summary collapse
-
#hotfixes ⇒ Array<String>
Output only.
-
#secure_boot_mode ⇒ String
Output only.
-
#windows_machine_domain ⇒ String
Output only.
-
#windows_user_domain ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WindowsSpecificDeviceAttributes
constructor
A new instance of WindowsSpecificDeviceAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WindowsSpecificDeviceAttributes
Returns a new instance of WindowsSpecificDeviceAttributes.
4685 4686 4687 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hotfixes ⇒ Array<String>
Output only. The hotfixes installed on the device.
Corresponds to the JSON property hotfixes
4666 4667 4668 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4666 def hotfixes @hotfixes end |
#secure_boot_mode ⇒ String
Output only. Secure boot mode of the device.
Corresponds to the JSON property secureBootMode
4671 4672 4673 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4671 def secure_boot_mode @secure_boot_mode end |
#windows_machine_domain ⇒ String
Output only. The domain of the machine that the user is logged into. This is
different from the windows_user_domain as the user could be logged into a
domain different from the machine domain.
Corresponds to the JSON property windowsMachineDomain
4678 4679 4680 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4678 def windows_machine_domain @windows_machine_domain end |
#windows_user_domain ⇒ String
Output only. The domain of the user account that is logged into the machine.
Corresponds to the JSON property windowsUserDomain
4683 4684 4685 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4683 def windows_user_domain @windows_user_domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4690 4691 4692 4693 4694 4695 |
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4690 def update!(**args) @hotfixes = args[:hotfixes] if args.key?(:hotfixes) @secure_boot_mode = args[:secure_boot_mode] if args.key?(:secure_boot_mode) @windows_machine_domain = args[:windows_machine_domain] if args.key?(:windows_machine_domain) @windows_user_domain = args[:windows_user_domain] if args.key?(:windows_user_domain) end |