Class: Google::Apis::CloudidentityV1beta1::WindowsSpecificDeviceAttributes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1beta1/classes.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb,
lib/google/apis/cloudidentity_v1beta1/representations.rb

Overview

Represents the Windows specific attributes of a Device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsSpecificDeviceAttributes

Returns a new instance of WindowsSpecificDeviceAttributes.



4684
4685
4686
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hotfixesArray<String>

Output only. The hotfixes installed on the device. Corresponds to the JSON property hotfixes

Returns:

  • (Array<String>)


4665
4666
4667
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4665

def hotfixes
  @hotfixes
end

#secure_boot_modeString

Output only. Secure boot mode of the device. Corresponds to the JSON property secureBootMode

Returns:

  • (String)


4670
4671
4672
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4670

def secure_boot_mode
  @secure_boot_mode
end

#windows_machine_domainString

Output only. The domain of the machine that the user is logged into. This is different from the windows_user_domain as the user could be logged into a domain different from the machine domain. Corresponds to the JSON property windowsMachineDomain

Returns:

  • (String)


4677
4678
4679
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4677

def windows_machine_domain
  @windows_machine_domain
end

#windows_user_domainString

Output only. The domain of the user account that is logged into the machine. Corresponds to the JSON property windowsUserDomain

Returns:

  • (String)


4682
4683
4684
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4682

def windows_user_domain
  @windows_user_domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4689
4690
4691
4692
4693
4694
# File 'lib/google/apis/cloudidentity_v1beta1/classes.rb', line 4689

def update!(**args)
  @hotfixes = args[:hotfixes] if args.key?(:hotfixes)
  @secure_boot_mode = args[:secure_boot_mode] if args.key?(:secure_boot_mode)
  @windows_machine_domain = args[:windows_machine_domain] if args.key?(:windows_machine_domain)
  @windows_user_domain = args[:windows_user_domain] if args.key?(:windows_user_domain)
end